package com.air.applets.controller;

import com.air.land.entity.LandListedConstructionPlan;
import com.air.land.service.LandListedConstructionPlanService;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.cinderella.framework.common.core.util.R;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;


/**
 * 小程序已挂牌地块关联建设规划管理
 *
 * @author peihao
 * @date 2021-06-17 20:07:27
 */
@RestController("applets_landlistedconstructionplan")
@AllArgsConstructor
@RequestMapping("/applets/landlistedconstructionplan")
@Api(value = "landlistedconstructionplan", tags = "小程序已挂牌地块关联建设规划管理")
public class LandListedConstructionPlanController {

    private final LandListedConstructionPlanService landListedConstructionPlanService;

    /**
     * 通过已挂牌地块id查询建设规划管理
     *
     * @param landListedId 已挂牌地块id
     * @return
     */
    @ApiOperation(value = "通过已挂牌地块id查询建设规划管理", notes = "通过已挂牌地块id查询建设规划管理")
    @GetMapping("/list/{landListedId}")
    public R getLandListedConstructionPlanPage(@PathVariable String landListedId) {
        List<LandListedConstructionPlan> list = landListedConstructionPlanService.list(Wrappers.<LandListedConstructionPlan>query()
                .lambda().eq(LandListedConstructionPlan::getLandListedId, landListedId));
        return R.ok(list, "查询成功");
    }

    /**
     * 通过id查询已挂牌地块关联建设规划
     *
     * @param constructionPlanId id
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/{constructionPlanId}")
    public R getById(@PathVariable("constructionPlanId") Long constructionPlanId) {
        return R.ok(landListedConstructionPlanService.getById(constructionPlanId));
    }
}
