package com.air.applets.controller;

import com.air.land.entity.LandToListConstructionPlan;
import com.air.land.service.LandToListConstructionPlanService;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.cinderella.framework.common.core.util.R;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;


/**
 * 小程序拟挂牌地块关联建设规划
 *
 * @author peihao
 * @date 2021-06-17 20:07:50
 */
@RestController("applets_landtolistconstructionplan")
@AllArgsConstructor
@RequestMapping("/applets/landtolistconstructionplan")
@Api(value = "landtolistconstructionplan", tags = "小程序拟挂牌地块关联建设规划")
public class LandToListConstructionPlanController {

    private final LandToListConstructionPlanService landToListConstructionPlanService;

    /**
     * 通过拟挂牌地块id查询建设规划管理
     *
     * @param proposedseriaId 拟挂牌地块id
     * @return
     */
    @ApiOperation(value = "通过拟挂牌地块id查询建设规划管理", notes = "通过拟挂牌地块id查询建设规划管理")
    @GetMapping("/list/{proposedseriaId}")
    public R getLandListedConstructionPlanPage(@PathVariable String proposedseriaId) {
        List<LandToListConstructionPlan> list = landToListConstructionPlanService.list(Wrappers.<LandToListConstructionPlan>query()
                .lambda().eq(LandToListConstructionPlan::getProposedseriaId, proposedseriaId));
        return R.ok(list, "查询成功");
    }


    /**
     * 通过id查询拟挂牌地块关联建设规划
     *
     * @param constructionPlanId id
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/{constructionPlanId}")
    public R getById(@PathVariable("constructionPlanId") Long constructionPlanId) {
        return R.ok(landToListConstructionPlanService.getById(constructionPlanId));
    }
}
