package com.air.applets.controller;

import cn.hutool.core.collection.CollectionUtil;
import com.air.applets.entity.LandUserKeep;
import com.air.applets.entity.ViewLand;
import com.air.applets.service.LandUserKeepService;
import com.air.applets.vo.LandUserKeepVo;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.cinderella.framework.common.core.util.R;
import com.cinderella.framework.common.data.mybatis.QueryPage;
import com.cinderella.framework.common.security.annotation.Inner;
import com.cinderella.framework.common.security.util.SecurityUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Optional;


/**
 * @author peihao
 * @date 2021-11-25 15:47:04
 */
@RestController
@AllArgsConstructor
@RequestMapping("/landUserKeep")
@Api(value = "landUserKeep", tags = "小程序用户地块收藏管理")
@Slf4j
public class LandUserKeepController {

    private final LandUserKeepService userKeepService;

    /**
     * 分页查询
     *
     * @param page         分页对象
     * @param landUserKeepVo
     * @return
     */
    @ApiOperation(value = "分页查询", notes = "分页查询")
    @PostMapping("/page")
    public R<IPage<ViewLand>> getLandUserKeepPage( QueryPage page,@RequestBody @Validated LandUserKeepVo landUserKeepVo) {
        log.info("用户收藏查询参数==={}",landUserKeepVo);
        return R.ok(userKeepService.getLandUserKeepPage(page.toPage(), landUserKeepVo));
    }

    /**
     * 新增用户收藏地块
     *
     * @param landUserKeep
     * @return R
     */
    @ApiOperation(value = "新增用户收藏地块", notes = "新增用户收藏地块")
    @PostMapping
    public R<Integer> save(@RequestBody @Validated LandUserKeep landUserKeep) {
        //查询用户每个地区是否添加至20条
        Optional<Integer> integer = userKeepService.verifyCollectNumber(landUserKeep.getLandId(), landUserKeep.getLandType(),SecurityUtils.getUser().getId());
        if (integer.isPresent()) {
            return R.failed("该城市收藏数量已达上限！");
        }
        //查询地块是否添加
        Optional<Integer> optional = userKeepService.verifyCollect(landUserKeep.getLandId(), landUserKeep.getLandType());
        if (optional.isPresent()) {
            return R.failed(optional.get(),"该地块已收藏，无需再次收藏");
        }
        landUserKeep.setUserId(SecurityUtils.getUser().getId());
        userKeepService.save(landUserKeep);
        return R.ok(landUserKeep.getId(),"保存成功");
    }

    @ApiOperation(value = "校验用户是否已收藏该地块", notes = "校验用户是否已收藏该地块（0：待挂牌，1：已挂牌）")
    @GetMapping
    public R<Integer> verifyCollect(@RequestParam String landId,@RequestParam Integer landType) {
        Optional<Integer> optional = userKeepService.verifyCollect(landId, landType);
        if (optional.isPresent()) {
            return R.failed(optional.get(),"该地块已收藏，无需再次收藏");
        }
        return R.ok(null,"可以收藏");
    }

    /**
     * 通过id批量删除
     *
     * @param ids ids
     * @return R
     */
    @ApiOperation(value = "通过id批量删除", notes = "通过id批量删除")
    @DeleteMapping("removeByIds")
    public R<Boolean> removeByIds(@RequestParam List<Integer> ids) {
        log.info("{}",ids.size());
        return R.ok(userKeepService.removeByIds(ids), "删除成功");
    }
}
