package com.air.applets.controller;

import cn.hutool.core.util.StrUtil;
import com.air.applets.entity.PlanSpot;
import com.air.applets.service.PlanSpotService;
import com.air.applets.vo.PlanLandSpotVo;
import com.alibaba.druid.util.StringUtils;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.cinderella.framework.common.core.util.R;
import com.cinderella.framework.common.data.mybatis.QueryPage;
import com.cinderella.framework.common.security.util.SecurityUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;


/**
 * @author peihao
 * @date 2021-11-25 15:47:04
 */
@RestController
@AllArgsConstructor
@RequestMapping("/planSpot")
@Api(value = "planSpot", tags = "小程序看地计划点位管理")
public class PlanSpotController {

    private final PlanSpotService planSpotService;

    /**
     * 分页查询
     *
     * @param page     分页对象
     * @param planSpot
     * @return
     */
    @ApiOperation(value = "分页查询", notes = "分页查询")
    @GetMapping("/page")
    public R<IPage<PlanSpot>> getPlanSpotPage(QueryPage page, PlanSpot planSpot) {
        return R.ok(planSpotService.page(page.toPage(), Wrappers.query(planSpot)));
    }


    /**
     * 通过计划id查询详情
     *
     * @param planId planId
     * @return R
     */
    @ApiOperation(value = "通过计划id查询详情", notes = "通过计划id查询详情")
    @GetMapping("/getSpotListByPlanId/{planId}")
    public R<PlanLandSpotVo> getSpotListByPlanId(@PathVariable("planId") Integer planId) {
        return R.ok(planSpotService.getSpotListByPlanId(planId), "查询成功");
    }

    /**
     * 新增计划详情（包含点位和计划基础信息）
     *
     * @param planLandSpotVo
     * @return R
     */
    @ApiOperation(value = "新增计划详情（包含点位和计划基础信息）", notes = "新增计划详情（包含点位和计划基础信息）")
    @PostMapping
    public R<Boolean> save(@RequestBody @Validated PlanLandSpotVo planLandSpotVo) {
        return R.ok(planSpotService.savePlanSpot(planLandSpotVo), "保存成功");
    }

    /**
     * 修改计划详情（包含点位和计划基础信息）
     *
     * @param planLandSpotVo
     * @return R
     */
    @ApiOperation(value = "修改计划详情（包含点位和计划基础信息）", notes = "修改计划详情（包含点位和计划基础信息）")
    @PutMapping
    public R<Boolean> updateById(@RequestBody @Validated PlanLandSpotVo planLandSpotVo) {
        String createUserId = planLandSpotVo.getPlanLandVo().getCreateUserId();
        if (StrUtil.isEmpty(createUserId)){
          return   R.failed("创建用户id不能为空");
        }
        if (!createUserId.equals(SecurityUtils.getUserId().toString())){
            return   R.failed("没有权限修改");
        }
        return R.ok(planSpotService.updatePlanSpot(planLandSpotVo), "保存成功");
    }

    /**
     * 通过点位id批量删除
     *
     * @param ids ids
     * @return R
     */
    @ApiOperation(value = "通过点位id批量删除", notes = "通过点位id批量删除")
    @DeleteMapping("removeByIds")
    public R<Boolean> removeByIds(@RequestParam List<Integer> ids) {
        return R.ok(planSpotService.removeByIds(ids));
    }
}
