package com.air.applets.controller;

import cn.hutool.core.util.StrUtil;
import com.air.enums.SysMessageStatusEnum;
import com.air.sysMessage.entity.SysMessage;
import com.air.sysMessage.service.SysMessageService;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cinderella.framework.common.core.util.R;
import com.cinderella.framework.common.data.mybatis.QueryPage;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;



/**
 * 小程序消息管理
 * @author peihao
 * @date 2021/7/14
 **/
@RestController("applets_sysMessage")
@AllArgsConstructor
@RequestMapping("/applets/message")
@Api(value = "message", tags = "小程序消息管理")
public class SysMessageController {

    private final  SysMessageService sysMessageService;

    /**
     * 分页查询
     * @param page 分页对象
     * @param messageType 消息类型
     * @return
     */
    @ApiOperation(value = "分页查询", notes = "分页查询")
    @GetMapping("/page")
    public R getSysMessagePage(QueryPage page, String messageType) {
        Page<SysMessage> result = sysMessageService.page(page.toPage(), Wrappers.<SysMessage>query().lambda()
                .eq(StrUtil.isNotEmpty(messageType),SysMessage::getMessageType, messageType)
                .eq(SysMessage::getStatusCd, SysMessageStatusEnum.SYS_MESSAGE_STATUS_1000.getCode())
                .orderByDesc(SysMessage::getCreateDate));
        return R.ok(result);
    }

    /**
     * 通过id查询系统消息
     * @param messageId id
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/{messageId}")
    public R getById(@PathVariable("messageId") Long messageId) {
        return R.ok(sysMessageService.getSysMessageDetail(messageId));
    }

    /**
     * 新增系统消息
     * @param sysMessage 系统消息
     * @return R
     */
    @ApiOperation(value = "新增系统消息", notes = "新增系统消息")
    @PostMapping
    public R save(@RequestBody @Validated SysMessage sysMessage) {
        return R.ok(sysMessageService.saveSysMessage(sysMessage));
    }

    /**
     * 修改系统消息
     * @param sysMessage 系统消息
     * @return R
     */
    @ApiOperation(value = "修改系统消息", notes = "修改系统消息")
    @PutMapping
    public R updateById(@RequestBody @Validated SysMessage sysMessage) {
        return R.ok(sysMessageService.updateSysMessage(sysMessage));
    }

    /**
     * 通过id删除系统消息
     * @param messageId id
     * @return R
     */
    @ApiOperation(value = "通过id删除系统消息", notes = "通过id删除系统消息")
    @DeleteMapping("/{messageId}")
    public R removeById(@PathVariable Long messageId) {
        return R.ok(sysMessageService.deleteSysMessage(messageId));
    }


    @ApiOperation(value = "发布消息", notes = "发布消息")
    @GetMapping("/publish/{messageId}")
    public R publishSysMessage(@PathVariable Long messageId) {
        return R.ok(sysMessageService.publishSysMessage(messageId));
    }
}
