package com.air.applets.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollectionUtil;
import com.air.applets.entity.PlanLand;
import com.air.applets.mapper.PlanLandMapper;
import com.air.applets.service.PlanLandService;
import com.air.applets.vo.PlanLandSpotVo;
import com.air.applets.vo.PlanLandVo;
import com.air.applets.vo.PlanSpotVo;
import com.air.utils.DateUtil;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.air.applets.entity.PlanSpot;
import com.air.applets.mapper.PlanSpotMapper;
import com.air.applets.service.PlanSpotService;
import com.cinderella.framework.common.core.exception.BusinessException;
import com.cinderella.framework.common.security.util.SecurityUtils;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDate;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 
 *
 * @author peihao
 * @date 2021-11-25 15:47:04
 */
@Service
@AllArgsConstructor
public class PlanSpotServiceImpl extends ServiceImpl<PlanSpotMapper, PlanSpot> implements PlanSpotService {

    private PlanLandMapper planLandMapper;

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean savePlanSpot(PlanLandSpotVo planLandSpotVo) {
        PlanLandVo planLandVo = planLandSpotVo.getPlanLandVo();
        PlanLand planLand = new PlanLand();
        BeanUtil.copyProperties(planLandVo,planLand);
        planLand.setPlanName(DateUtil.fromString(LocalDate.now(),"yyyy-MM-dd")+" 看地计划");
        planLand.setCreateUserId(SecurityUtils.getUser().getId().toString());
        planLandMapper.insert(planLand);

        List<PlanSpot> planSpots = planLandSpotVo.getPlanSpotVos().stream().map(e -> {
            PlanSpot planSpot = new PlanSpot();
            BeanUtil.copyProperties(e, planSpot);
            planSpot.setPlanId(planLand.getId());
            return planSpot;
        }).collect(Collectors.toList());
        return this.saveBatch(planSpots);
    }

    @Transactional(rollbackFor = Exception.class)
    @Override
    public boolean updatePlanSpot(PlanLandSpotVo planLandSpotVo) {
        PlanLandVo planLandVo = planLandSpotVo.getPlanLandVo();
        if (planLandVo.getId() == null){
            throw new BusinessException("计划id不能为空");
        }
        PlanLand planLand = new PlanLand();
        BeanUtil.copyProperties(planLandVo,planLand);
        planLandMapper.updateById(planLand);

        List<PlanSpot> planSpots = planLandSpotVo.getPlanSpotVos().stream().map(e -> {
            if (null == e.getPlanId()){
                throw new BusinessException("计划id不能为空");
            }
            PlanSpot planSpot = new PlanSpot();
            BeanUtil.copyProperties(e, planSpot);
            return planSpot;
        }).collect(Collectors.toList());
        this.remove(Wrappers.<PlanSpot>query().lambda().eq(PlanSpot::getPlanId,planLand.getId()));
        return this.saveBatch(planSpots);
    }

    @Override
    public PlanLandSpotVo getSpotListByPlanId(Integer planId) {
        PlanLand plan = planLandMapper.selectById(planId);
        if (null == plan){
            throw new BusinessException("计划id有误，未查询到数据");
        }
        List<PlanSpot> planSpots = this.list(Wrappers.<PlanSpot>query().lambda()
                .eq(PlanSpot::getPlanId, planId).orderByAsc(PlanSpot::getSpotSort));

        PlanLandSpotVo planLandSpotVo = new PlanLandSpotVo();
        PlanLandVo planLandVo = new PlanLandVo();
        BeanUtil.copyProperties(plan,planLandVo);
        planLandSpotVo.setPlanLandVo(planLandVo);
        if (CollectionUtil.isNotEmpty(planSpots)){
            List<PlanSpotVo> planSpotVos = planSpots.stream().map(e -> {
                PlanSpotVo planSpotVo = new PlanSpotVo();
                BeanUtil.copyProperties(e, planSpotVo);
                return planSpotVo;
            }).collect(Collectors.toList());
            planLandSpotVo.setPlanSpotVos(planSpotVos);
        }
        return planLandSpotVo;
    }

}
