package com.air.applets.vo;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.math.BigDecimal;

/**
 * 测算数据
 *
 * @author peihao
 * @date 2021/5/18
 **/
@Data
@ApiModel(value = "测算数据")
public class MeasureDataVo {
    private static final long serialVersionUID = 1L;

    @ApiModelProperty(value = "测算数据id")
    private Long measureDataId;

    @ApiModelProperty(value = "已挂牌地块标识")
    private String landListedId;

    @ApiModelProperty(value = "拟挂牌地块序号")
    private String proposedseriaId;

    @NotNull(message = "测算类型不能为空")
    @ApiModelProperty(value = "测算类型（0：基础，1：高级）")
    private Integer measureType;

    @ApiModelProperty(value = "土地编号")
    private String annoId;

    @ApiModelProperty(value = "住宅定价")
    private BigDecimal housingPrice;

    @ApiModelProperty(value = "商业定价")
    private BigDecimal commercePrice;

    @ApiModelProperty(value = "商务定价")
    private BigDecimal businessPrice;

    @ApiModelProperty(value = "车位配比（个/100㎡）")
    private BigDecimal parkingAllocation;

    @ApiModelProperty(value = "单车指标")
    private BigDecimal singleIndicator;

    @ApiModelProperty(value = "车位可售")
    private BigDecimal parkingSaleRate;

    @ApiModelProperty(value = "单方成本")
    private BigDecimal singlePrimeCost;

    @ApiModelProperty(value = "车位定价")
    private BigDecimal parkingPrice;

    @ApiModelProperty(value = "商业配比")
    private BigDecimal commerceRate;

    @ApiModelProperty(value = "商务配比")
    private BigDecimal businessRate;

    @ApiModelProperty(value = "管理费率")
    private BigDecimal manageFeeRate;

    @ApiModelProperty(value = "销售费率")
    private BigDecimal salesRate;

    @ApiModelProperty(value = "财务费率")
    private BigDecimal financialRate;

    @ApiModelProperty(value = "前融比例")
    private BigDecimal financingRate;

    @ApiModelProperty(value = "前融利率")
    private BigDecimal financingInterest;

    @ApiModelProperty(value = "前融周期")
    private Integer financingPeriod;

    @ApiModelProperty(value = "开发贷比例")
    private BigDecimal loansRate;

    @ApiModelProperty(value = "开发贷利率")
    private BigDecimal loansInterest;

    @ApiModelProperty(value = "开发贷周期")
    private Integer loansPeriod;

    @ApiModelProperty(value = "无偿移交住宅计容占比")
    private BigDecimal freeHousingRate;

    @ApiModelProperty(value = "无偿移交商业计容占比")
    private BigDecimal freeCommerceRate;

    @ApiModelProperty(value = "无偿移交商务计容占比")
    private BigDecimal freeBusinessRate;

    @ApiModelProperty(value = "自持住宅计容占比")
    private BigDecimal selfHousingRate;

    @ApiModelProperty(value = "住宅可售数量")
    private Integer selfHousingSale;

    @ApiModelProperty(value = "住宅可售价格")
    private BigDecimal selfHousingPrice;

    @ApiModelProperty(value = "自持商业计容占比")
    private BigDecimal selfCommerceRate;

    @ApiModelProperty(value = "商业可售数量")
    private Integer selfCommerceSale;

    @ApiModelProperty(value = "商业可售价格")
    private BigDecimal selfCommercePrice;

    @ApiModelProperty(value = "自持商务计容占比")
    private BigDecimal selfBusinessRate;

    @ApiModelProperty(value = "商务可售数量")
    private Integer selfBusinessSale;

    @ApiModelProperty(value = "商务可售价格")
    private BigDecimal selfBusinessPrice;

    @ApiModelProperty(value = "起拍楼面价")
    private BigDecimal floorPrice;

    @ApiModelProperty(value = "土地总价")
    private BigDecimal landTotalPrice;

    @ApiModelProperty(value = "净利率")
    private BigDecimal netProfitRatio;

    @ApiModelProperty(value = "溢价率")
    private BigDecimal premiumRate;

    @ApiModelProperty(value = "预测楼面价")
    private BigDecimal forecastFloorPrice;

    @ApiModelProperty(value = "预测土地总价")
    private BigDecimal forecastLandTotalPrice;

    @ApiModelProperty(value = "预测净利率")
    private BigDecimal forecastNetProfitRatio;

    @ApiModelProperty(value = "预测溢价率")
    private BigDecimal forecastPremiumRate;

    @ApiModelProperty(value = "成交楼面价")
    private BigDecimal transactionFloorPrice;

    @ApiModelProperty(value = "是否准确")
    private Long accuracy;

    @ApiModelProperty(value = "误差绝对值")
    private BigDecimal errorAbsoluteValue;

    @NotBlank(message = "保存状态不能为空")
    @ApiModelProperty(value = "状态（1000:提交，1100：保存）",notes = "保存状态无法进行修改")
    private String statusCd;
}
