package com.air.cityarea.controller;

import cn.hutool.core.collection.CollectionUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cinderella.framework.common.core.util.R;
import com.cinderella.framework.common.data.mybatis.QueryPage;
import com.air.cityarea.entity.RotateGroup;
import com.air.cityarea.service.RotateGroupService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;


/**
 * 轮播分组
 *
 * @author peihao
 * @date 2021-10-08 17:24:48
 */
@RestController
@AllArgsConstructor
@RequestMapping("/rotateGroup")
@Api(value = "rotateGroup", tags = "轮播分组管理")
public class RotateGroupController {

    private final  RotateGroupService rotateGroupService;

    /**
     * 分页查询
     * @param page 分页对象
     * @param rotateGroup 轮播分组
     * @return
     */
    @ApiOperation(value = "分页查询", notes = "分页查询")
    @GetMapping("/page")
    public R<IPage<RotateGroup>> getRotateGroupPage(QueryPage page, RotateGroup rotateGroup) {
        return R.ok(rotateGroupService.page(page.toPage(), Wrappers.query(rotateGroup)));
    }

    /**
     * 查询分组
     * @return R
     */
    @ApiOperation(value = "查询分组", notes = "查询分组")
    @GetMapping("getGroupName")
    public R<Map<Long,String>> getGroupName() {
        List<RotateGroup> list = rotateGroupService.list();
        if (CollectionUtil.isNotEmpty(list)){
            return R.ok(list.stream().collect(Collectors.toMap(RotateGroup::getGroupId, RotateGroup::getGroupName)),"查询成功");
        }
        return R.ok();
    }


    /**
     * 通过id查询轮播分组
     * @param groupId id
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/{groupId}")
    public R<RotateGroup> getById(@PathVariable("groupId") Long groupId) {
        return R.ok(rotateGroupService.getById(groupId));
    }

    /**
     * 新增轮播分组
     * @param rotateGroup 轮播分组
     * @return R
     */
    @ApiOperation(value = "新增轮播分组", notes = "新增轮播分组")
    @PostMapping
    public R save(@RequestBody RotateGroup rotateGroup) {
        return R.ok(rotateGroupService.save(rotateGroup));
    }

    /**
     * 修改轮播分组
     * @param rotateGroup 轮播分组
     * @return R
     */
    @ApiOperation(value = "修改轮播分组", notes = "修改轮播分组")
    @PutMapping
    public R updateById(@RequestBody RotateGroup rotateGroup) {
        return R.ok(rotateGroupService.updateById(rotateGroup));
    }

    /**
     * 通过id删除轮播分组
     * @param groupId id
     * @return R
     */
    @ApiOperation(value = "通过id删除轮播分组", notes = "通过id删除轮播分组")
    @DeleteMapping("/{groupId}")
    public R removeById(@PathVariable Long groupId) {
        return R.ok(rotateGroupService.removeById(groupId));
    }
}
