package com.air.cityarea.controller;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.StrUtil;
import com.air.cityarea.entity.RotateGroup;
import com.air.cityarea.service.RotateGroupService;
import com.air.cityarea.vo.RotateImageStatusVo;
import com.air.enums.RotateStatusEnum;
import com.air.utils.FileUtil;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cinderella.framework.common.core.util.R;
import com.cinderella.framework.common.data.mybatis.QueryPage;
import com.air.cityarea.entity.RotateImage;
import com.air.cityarea.service.RotateImageService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.constraints.NotNull;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;


/**
 * 轮播图片
 *
 * @author peihao
 * @date 2021-10-08 17:24:48
 */
@RestController
@AllArgsConstructor
@RequestMapping("/rotateImage")
@Api(value = "rotateImage", tags = "轮播图片管理")
public class RotateImageController {

    private final  RotateImageService rotateImageService;

    private final RotateGroupService rotateGroupService;

    private final FileUtil fileUtil;

    /**
     * 分页查询
     * @param page 分页对象
     * @param image 轮播图片
     * @return
     */
    @ApiOperation(value = "分页查询", notes = "分页查询")
    @GetMapping("/page")
    public R getRotateImagePage(QueryPage page, RotateImage image) {
        Page<RotateImage> rotateImagePage = rotateImageService.page(page.toPage(), Wrappers.<RotateImage>query().lambda()
                .eq(StrUtil.isNotEmpty(image.getStatusCd()),RotateImage::getStatusCd,image.getStatusCd())
                .eq(image.getGroupId() != null,RotateImage::getGroupId,image.getGroupId())
                .like(StrUtil.isNotEmpty(image.getImageName()),RotateImage::getImageName,image.getImageName())
                .orderByDesc(RotateImage::getCreateDate));
        List<RotateImage> records = rotateImagePage.getRecords();
        if (CollectionUtil.isNotEmpty(records)){
            List<Long> groupIds = records.stream().map(e -> e.getGroupId()).collect(Collectors.toList());
            List<RotateGroup> rotateGroups = rotateGroupService.listByIds(groupIds);
            Map<Long, String> map = new HashMap<>();
            rotateGroups.stream().forEach(e ->{
                map.put(e.getGroupId(),e.getGroupName());
            });
            records.stream().forEach(e ->{
                e.setGroupName(map.get(e.getGroupId()));
                e.setImagePath(fileUtil.getUrlByInnerPath(e.getImagePath()));
                e.setStatusName(RotateStatusEnum.getName(e.getStatusCd()));
            });
        }

        return R.ok(rotateImagePage);
    }


    /**
     * 通过id查询轮播图片
     * @param id id
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/{id}")
    public R getById(@PathVariable("id") Long id) {
        RotateImage rotateImage = rotateImageService.getById(id);
        rotateImage.setImagePath(fileUtil.getUrlByInnerPath(rotateImage.getImagePath()));
        return R.ok(rotateImage);
    }

    /**
     * 新增轮播图片
     * @param rotateImage 轮播图片
     * @return R
     */
    @ApiOperation(value = "新增轮播图片", notes = "新增轮播图片")
    @PostMapping
    public R save(@RequestBody @Validated RotateImage rotateImage) {
        return R.ok(rotateImageService.save(rotateImage));
    }

    /**
     * 修改轮播图片
     * @param rotateImage 轮播图片
     * @return R
     */
    @ApiOperation(value = "修改轮播图片", notes = "修改轮播图片")
    @PutMapping
    public R updateById(@RequestBody @Validated RotateImage rotateImage) {
        if (rotateImage.getId() == null){
            return R.failed("id不能为空");
        }
        rotateImage.setImagePath(fileUtil.getInnerPath(rotateImage.getImagePath()));
        return R.ok(rotateImageService.updateById(rotateImage));
    }

    /**
     * 修改轮播图状态
     * @param statusVo
     * @return R
     */
    @ApiOperation(value = "修改轮播图状态", notes = "修改轮播图状态")
    @PutMapping("updateStatus")
    public R updateStatus(@RequestBody @Validated RotateImageStatusVo statusVo) {
        RotateImage rotateImage = new RotateImage();
        BeanUtil.copyProperties(statusVo,rotateImage);
        return R.ok(rotateImageService.updateById(rotateImage));
    }

    /**
     * 通过id删除轮播图片
     * @param ids ids
     * @return R
     */
    @ApiOperation(value = "通过id删除轮播图片", notes = "通过id删除轮播图片")
    @DeleteMapping("deleteByIds")
    public R deleteByIds(@RequestParam List<Long> ids) {
        return R.ok(rotateImageService.removeByIds(ids));
    }
}
