package com.air.common.service.impl;

import cn.hutool.core.lang.UUID;
import cn.hutool.core.util.StrUtil;
import com.air.common.service.SysFileUploadService;
import com.air.common.vo.SysFileUploadVo;
import com.cinderella.framework.common.core.util.R;
import com.cinderella.framework.common.minio.service.MinioTemplate;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

/**
 * 文件记录
 *
 * @author zeb
 * @date 2019-05-16 14:49:03
 */
@Service
@Slf4j
public class SysFileUploadServiceImpl implements SysFileUploadService {

    @Autowired
    private MinioTemplate minioTemplate;

    @Value("${minio.down-url}")
    private String minioDownUrl;

    @SneakyThrows
    @Override
    public R upload(MultipartFile file, String bucketName) {
        String fileType = StringUtils.substringAfterLast(file.getOriginalFilename(), ".");
        String minioFileName = UUID.fastUUID().toString() + StrUtil.DOT + fileType.toLowerCase();
        try {
            minioTemplate.putObject(bucketName, minioFileName, file.getInputStream());
        } catch (Exception e) {
             log.error("上传失败", e);
            return R.failed("上传失败，请重新上传");
        }

        String objectURL = "/" + bucketName + "/" + minioFileName;
        String previewUrl = minioDownUrl+objectURL;
        SysFileUploadVo sysFileUploadVo = new SysFileUploadVo();
        sysFileUploadVo.setFileName(file.getOriginalFilename());
        sysFileUploadVo.setPath(objectURL);
        sysFileUploadVo.setPreviewUrl(previewUrl);
        return R.ok(sysFileUploadVo, "上传成功");

    }


}
