package com.air.feedback.controller;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cinderella.framework.common.core.util.R;
import com.air.feedback.entity.Feedback;
import com.air.feedback.service.FeedbackService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;


/**
 * 意见反馈
 *
 * @author fnmdx
 * @date 2021-05-25 10:50:49
 */
@RestController
@AllArgsConstructor
@RequestMapping("/feedback")
@Api(value = "feedback", tags = "意见反馈管理")
public class FeedbackController {

    private final  FeedbackService feedbackService;

    /**
     * 分页查询
     * @param page 分页对象
     * @param feedback 意见反馈
     * @return
     */
    @ApiOperation(value = "分页查询", notes = "分页查询")
    @GetMapping("/page")
    public R getFeedbackPage(Page page, Feedback feedback) {
        return R.ok(feedbackService.getFeedBackPage(page,feedback));
    }


    /**
     * 通过id查询意见反馈
     * @param feedbackId id
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/{feedbackId}")
    public R getById(@PathVariable("feedbackId") Long feedbackId) {
        return R.ok(feedbackService.getFeedBackDetail(feedbackId));
    }

    /**
     * 新增意见反馈
     * @param feedback 意见反馈
     * @return R
     */
    @ApiOperation(value = "新增意见反馈", notes = "新增意见反馈")
    @PostMapping
    public R save(@RequestBody Feedback feedback) {
        return R.ok(feedbackService.saveFeedBack(feedback));
    }

    /**
     * 修改意见反馈
     * @param feedback 意见反馈
     * @return R
     */
    @ApiOperation(value = "修改意见反馈", notes = "修改意见反馈")
    @PutMapping
    public R updateById(@RequestBody Feedback feedback) {
        return R.ok(feedbackService.updateFeedBack(feedback));
    }

    /**
     * 通过id删除意见反馈
     * @param feedbackId id
     * @return R
     */
    @ApiOperation(value = "通过id删除意见反馈", notes = "通过id删除意见反馈")
    @DeleteMapping("/{feedbackId}")
    public R removeById(@PathVariable Long feedbackId) {
        return R.ok(feedbackService.removeById(feedbackId));
    }

    @ApiOperation(value = "处理意见反馈", notes = "处理意见反馈")
    @GetMapping("/handle/{feedbackId}")
    public R handleFeedBack(@PathVariable Long feedbackId) {
        return R.ok(feedbackService.handleFeedBack(feedbackId));
    }
}
