package com.air.housing.controller;

import com.air.housing.dto.BlockListDto;
import com.air.housing.entity.Blocks;
import com.air.housing.service.BlocksService;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cinderella.framework.common.core.util.R;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;


/**
 * 楼栋信息
 *
 * @author peihao
 * @date 2021-05-18 09:39:45
 */
@RestController
@AllArgsConstructor
@RequestMapping("/blocks")
@Api(value = "blocks", tags = "楼栋信息管理")
public class BlocksController {

    private final BlocksService blocksService;

    @ApiOperation(value = "根据楼盘id分页查询楼栋", notes = "根据楼盘id分页查询楼栋")
    @GetMapping("/page")
    public R getBlocksPageByhousingEstateId(Page page, BlockListDto blocks) {
        return R.ok(blocksService.getBlocksPageByhousingEstateId(page, blocks));
    }

    /**
     * 通过id查询楼栋信息
     *
     * @param blockId id
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/{blockId}")
    public R getById(@PathVariable("blockId") Long blockId) {
        return R.ok(blocksService.getById(blockId));
    }

    /**
     * 通过id查询楼栋业态信息
     *
     * @param blockId id
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/commercial_activities/{blockId}")
    public R getByIds(@PathVariable("blockId") Long blockId) {

        return R.ok(blocksService.selectCommercialActivities(blockId));
    }


    /**
     * 新增楼栋信息
     *
     * @param blocks 楼栋信息
     * @return R
     */
    @ApiOperation(value = "新增楼栋信息", notes = "新增楼栋信息")
    @PostMapping
    @PreAuthorize("@pms.hasPermission('generator_blocks_add')")
    public R save(@RequestBody Blocks blocks) {
        return R.ok(blocksService.save(blocks));
    }

    /**
     * 修改楼栋信息
     *
     * @param blocks 楼栋信息
     * @return R
     */
    @ApiOperation(value = "修改楼栋信息", notes = "修改楼栋信息")
    @PutMapping
    @PreAuthorize("@pms.hasPermission('generator_blocks_edit')")
    public R updateById(@RequestBody Blocks blocks) {
        return R.ok(blocksService.updateById(blocks));
    }

    /**
     * 修改楼栋信息
     *
     * @param blocks 楼栋信息
     * @return R
     */
    @ApiOperation(value = "修改楼栋信息", notes = "修改楼栋信息")
    @PutMapping("/modify")
    public R updateByIdBlocks(@RequestBody Blocks blocks) {
        return R.ok(blocksService.updateByIdBlocks(blocks));
    }

    /**
     * 通过id删除楼栋信息
     *
     * @param blockId id
     * @return R
     */
    @ApiOperation(value = "通过id删除楼栋信息", notes = "通过id删除楼栋信息")
    @DeleteMapping("/{blockId}")
    @PreAuthorize("@pms.hasPermission('generator_blocks_del')")
    public R removeById(@PathVariable Long blockId) {
        return R.ok(blocksService.removeById(blockId));
    }
}
