package com.air.housing.controller;

import com.air.housing.entity.Houses;
import com.air.housing.service.HousesService;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cinderella.framework.common.core.util.R;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;


/**
 * 房屋信息
 *
 * @author peihao
 * @date 2021-05-18 09:39:49
 */
@RestController
@AllArgsConstructor
@RequestMapping("/houses")
@Api(value = "houses", tags = "房屋信息管理")
public class HousesController {

    private final HousesService housesService;

    /**
     * 分页查询
     *
     * @param page   分页对象
     * @param houses 房屋信息
     * @return
     */
    @ApiOperation(value = "分页查询", notes = "分页查询")
    @GetMapping("/page")
    public R getHousesPage(Page page, Houses houses) {
        return R.ok(housesService.page(page, Wrappers.query(houses)));
    }


    /**
     * 通过id查询房屋信息
     *
     * @param houseId id
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/{houseId}")
    public R getById(@PathVariable("houseId") Long houseId) {
        return R.ok(housesService.getById(houseId));
    }

    /**
     * 通过楼栋id查询房屋信息
     *
     * @param blockId
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/house/{blockId}")
    public R getByBlockId(Page page, @PathVariable("blockId") Long blockId) {
        return R.ok(housesService.page(page, Wrappers.<Houses>lambdaQuery().eq(Houses::getBlockId, blockId)));
    }

    /**
     * 新增房屋信息
     *
     * @param houses 房屋信息
     * @return R
     */
    @ApiOperation(value = "新增房屋信息", notes = "新增房屋信息")
    @PostMapping
    public R save(@RequestBody Houses houses) {
        return R.ok(housesService.save(houses));
    }

    /**
     * 修改房屋信息
     *
     * @param houses 房屋信息
     * @return R
     */
    @ApiOperation(value = "修改房屋信息", notes = "修改房屋信息")
    @PutMapping
    public R updateById(@RequestBody Houses houses) {
        return R.ok(housesService.updateById(houses));
    }

    /**
     * 通过id删除房屋信息
     *
     * @param houseId id
     * @return R
     */
    @ApiOperation(value = "通过id删除房屋信息", notes = "通过id删除房屋信息")
    @DeleteMapping("/{houseId}")
    public R removeById(@PathVariable Long houseId) {
        return R.ok(housesService.removeById(houseId));
    }
}
