package com.air.housing.controller;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.StrUtil;
import com.air.common.Constant;
import com.air.housing.dto.HousingDefine;
import com.air.housing.dto.HousingEstatesQuery;
import com.air.housing.entity.HousingEstates;
import com.air.housing.service.HousingEstatesService;
import com.air.housing.vo.HousingEstatesDetail;
import com.air.housing.vo.HousingEstatesName;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.cinderella.framework.common.core.util.R;
import com.cinderella.framework.common.data.mybatis.QueryPage;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;


/**
 * 楼盘（小区）
 *
 * @author peihao
 * @date 2021-05-18 09:39:55
 */
@RestController
@AllArgsConstructor
@RequestMapping("/housing_estates")
@Api(value = "housing_estates", tags = "楼盘（小区）管理")
public class HousingEstatesController {

    private final HousingEstatesService housingEstatesService;

    /**
     * 分页查询
     *
     * @param page  分页对象
     * @param query 查询条件
     * @return
     */
    @ApiOperation(value = "分页查询", notes = "分页查询")
    @GetMapping("/page")
    public R getHousingEstatesPage(QueryPage page, HousingEstatesQuery query) {
        return R.ok(housingEstatesService.page(page, query));
    }

    @GetMapping("/page/housing_names")
    @ApiOperation(value = "查询楼盘名称（分页）")
    public R<IPage<HousingEstatesName>> getHousingEstatesNamePage(QueryPage page, String name) {
        return R.ok(housingEstatesService.getHousingEstatesNamePage(page.toPage(), name));
    }


//    @GetMapping("/page/housing_names/name")
    @ApiOperation(value = "查询楼盘名称")
    public R<List<HousingEstatesName>> getHousingEstatesNamePage( String name) {
        return R.ok(housingEstatesService.getHousingEstatesName( name));
    }

    @PostMapping("/create_from_origin")
    @ApiOperation(value = "提交楼盘定义信息")
    public R createFromOrigin(@RequestBody @Validated HousingDefine housingDefine) {
        if(CollectionUtil.isNotEmpty(housingDefine.getLandListedId()) && StrUtil.isEmpty(housingDefine.getHousingEstateName())){
            return R.failed("楼盘名称未填写");
        }
        return R.ok(housingEstatesService.createFromOrigin(housingDefine));
    }


    /**
     * 通过id查询楼盘（小区）
     *
     * @param housingEstateId id
     * @return R
     */
    @ApiOperation(value = "通过id查询详情", notes = "通过id查询详情")
    @GetMapping("/{housingEstateId}")
    public R getById(@PathVariable("housingEstateId") Long housingEstateId) {
        HousingEstatesDetail housingEstates = housingEstatesService.getHousingEstatesDetail(housingEstateId);
        return R.ok(housingEstates);
    }

    /**
     * 新增楼盘（小区）
     *
     * @param housingEstates 楼盘（小区）
     * @return R
     */
    @ApiOperation(value = "新增楼盘（小区）", notes = "新增楼盘（小区）")
    @PostMapping
    public R save(@RequestBody HousingEstates housingEstates) {
        housingEstates.setStatusCd(Constant.COMMON_STATUS_1000);
        return R.ok(housingEstatesService.save(housingEstates));
    }

    /**
     * 修改楼盘（小区）
     *
     * @param housingEstates 楼盘（小区）
     * @return R
     */
    @ApiOperation(value = "修改楼盘（小区）", notes = "修改楼盘（小区）")
    @PutMapping
    public R updateById(@RequestBody HousingEstates housingEstates) {
        return R.ok(housingEstatesService.updateById(housingEstates));
    }

    /**
     * 通过id删除楼盘（小区）
     *
     * @param housingEstateId id
     * @return R
     */
    @ApiOperation(value = "通过id删除楼盘（小区）", notes = "通过id删除楼盘（小区）")
    @DeleteMapping("/{housingEstateId}")
    public R removeById(@PathVariable Long housingEstateId) {
        return R.ok(housingEstatesService.removeById(housingEstateId));
    }
}
