package com.air.housing.service;

import com.air.housing.dto.HousingDefine;
import com.air.housing.dto.HousingEstatesQuery;
import com.air.housing.entity.HousingEstates;
import com.air.housing.vo.HousingEstatesDetail;
import com.air.housing.dto.HousingEstatesListDto;
import com.air.housing.vo.HousingEstatesName;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.IService;
import com.cinderella.framework.common.data.mybatis.QueryPage;

import java.util.List;

/**
 * 楼盘（小区）
 *
 * @author peihao
 * @date 2021-05-18 09:39:55
 */
public interface HousingEstatesService extends IService<HousingEstates> {
    /**
     * 查询楼盘名称
     * @param page
     * @param name
     * @return
     */
    IPage<HousingEstatesName> getHousingEstatesNamePage(IPage<HousingEstatesName> page, String name);


    /**
     * 查询楼盘名称
     * @param name
     * @return
     */
    List<HousingEstatesName> getHousingEstatesName(String name);

    /**
     * 提交楼盘定义信息
     * 根据前端提交的“楼盘id”（housingEstateId）字段是否为空来进行逻辑分支：
     * 如果housingEstateId不为空，根据前端传入的blockId，将blocks_origin表对应的字段，复制写入blocks表并新增主键，将houses_origin表中blokcId对应的数据，全部复制写入houses表，并新增主键，blocks_origin表的housing_estate_id字段为前端传入的housingEstateId，houses的block_id字段为复制时blocks表时的主键值；
     * 如果housingEstateId为空，则新增一条housing_estates表记录，其余与上一步描述操作一致；
     * 完成前两步逻辑之后，根据housingEstateId、前端传入的大业态、小业态标识，三个字段组合，确认format表中是否存在该组合数据，如果不存在则新增一条记录，如果已存在则不作处理，其余字段：业态首推时间、供应套数、供应面积、成交套数、成交面积等后续字段，遵循一定计算规则进行运算，该部分字段暂时不用理会。
     * @param housingDefine
     * @return true
     */
    boolean createFromOrigin(HousingDefine housingDefine);

    /**
     * 根据楼盘id查询楼盘信息和相关的地块信息，如果楼栋个id不为空，再查询业态信息
     * @param housingEstateId
     * @return
     */
    HousingEstatesDetail getHousingEstatesDetail(Long housingEstateId);

    /**
     * 分页
     * @param page
     * @param query
     * @return
     */
    IPage<HousingEstatesListDto> page(QueryPage page, HousingEstatesQuery query);
}
