package com.air.housing.service.impl;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.air.common.Constant;
import com.air.enums.BlocksOriginStatusEnum;
import com.air.housing.dto.HousingDefine;
import com.air.housing.dto.HousingEstatesListDto;
import com.air.housing.dto.HousingEstatesQuery;
import com.air.housing.entity.*;
import com.air.housing.mapper.AnnoBlocksRelMapper;
import com.air.housing.mapper.HousingEstatesMapper;
import com.air.housing.service.*;
import com.air.housing.vo.HousingEstatesDetail;
import com.air.housing.vo.HousingEstatesName;
import com.air.land.entity.LandListed;
import com.air.land.mapper.LandListedMapper;
import com.air.origin.entity.BlocksOrigin;
import com.air.origin.entity.HousesOrigin;
import com.air.origin.service.BlocksOriginService;
import com.air.origin.service.HousesOriginService;
import com.air.utils.RedisUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cinderella.framework.common.core.exception.BusinessException;
import com.cinderella.framework.common.data.mybatis.QueryPage;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.concurrent.ThreadPoolTaskExecutor;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import java.util.concurrent.TimeUnit;

/**
 * 楼盘（小区）
 *
 * @author peihao
 * @date 2021-05-18 09:39:55
 */
@Service
@Slf4j
public class HousingEstatesServiceImpl extends ServiceImpl<HousingEstatesMapper, HousingEstates> implements HousingEstatesService {

    @Autowired
    private BlocksOriginService blocksOriginService;
    @Autowired
    private BlocksService blocksService;
    @Autowired
    private HousesOriginService housesOriginService;
    @Autowired
    private HousesService housesService;
    @Autowired
    private HousingEstatesMapper housingEstatesMapper;
    @Autowired
    private AnnoBlocksRelService annoBlocksRelService;

    @Autowired
    private AnnoBlocksRelMapper annoBlocksRelMapper;
    @Autowired
    private LandListedMapper landListedMapper;
    @Autowired
    private FormatService formatService;

    @Autowired
    private RedisUtil redisUtil;

    @Autowired
    ThreadPoolTaskExecutor executor;


    @Override
    public IPage<HousingEstatesName> getHousingEstatesNamePage(IPage<HousingEstatesName> page, String name) {
        return housingEstatesMapper.getHousingEstatesNamePage(page, name);
    }

    @Override
    @Transactional
    public List<HousingEstatesName> getHousingEstatesName(String name) {
        //查询地块表
        List<LandListed> landListeds = landListedMapper.selectBuildingName();
        List<HousingEstatesName> housingEstatesNames = housingEstatesMapper.selectIName(name);
        List<HousingEstates> list = new ArrayList<>();
        //添加未添加的楼盘
        for ( HousingEstatesName housingEstatesName : housingEstatesNames) {
            for (LandListed landListed :  landListeds) {
                if(landListed.getBuildingName().equals(housingEstatesName.getName())){
                   // log.info("========================{}",landListed);
                   // log.info("==============数量=========={}",landListeds.size());
                    landListeds.remove(landListed);
                    break;
                }
            }
        }
//        landListeds.forEach( landName ->{
//            housingEstatesNames.forEach( housingName ->{
//                if(landName.getBuildingName().equals(housingName.getName())){
//                   landListeds.remove(landName.getBuildingName());
//                }
//            } );
//        });
        if(landListeds.size() > 0){

            landListeds.forEach(landListed -> {
                HousingEstates housingEstates = new HousingEstates();
                housingEstates.setName(landListed.getBuildingName());
                housingEstates.setStatusCd(Constant.COMMON_STATUS_1000);
                list.add(housingEstates);
            });
            log.info("添加的数量{}",list.size());
            this.saveBatch(list);
        }
        else{
            return housingEstatesNames;
        }

        //添加地块关联表
        List<LandListed> landListed = landListedMapper.selectBuildingNames(); //查询楼盘。编号
        List<HousingEstatesName> housingEstatesName = housingEstatesMapper.selectIName(name); //查询楼盘
        List<AnnoBlocksRel> annoBlocksRelList = new ArrayList<>();
        //添加地块关联表

            housingEstatesName.forEach( housingEstatesName1 -> {
                landListed.forEach( landListed1 -> {
                    if(housingEstatesName1.getName().equals(landListed1.getBuildingName())){
                        AnnoBlocksRel annoBlocksRel = new AnnoBlocksRel();
                        annoBlocksRel.setHousingEstatesId(housingEstatesName1.getHousingEstateId());
                        annoBlocksRel.setLandListedId(landListed1.getLandListedId());
                        Object object = redisUtil.getCacheObject("AA" + landListed1.getLandListedId());
                        if(ObjectUtil.isNotNull(object)){
                            annoBlocksRel.setMainLand(0);
                        }else{
                            redisUtil.setCacheObject("AA"+landListed1.getLandListedId() ,1,2, TimeUnit.MINUTES);
                            annoBlocksRel.setMainLand(1);
                        }
                        annoBlocksRel.setStatusCd(Constant.COMMON_STATUS_1000);
                        annoBlocksRelList.add(annoBlocksRel);
                    }
                });
            });
        if(annoBlocksRelList.size() > 0){
                List<AnnoBlocksRel> annoBlocksRelList1 = annoBlocksRelMapper.selectName();

                for ( AnnoBlocksRel annoBlocksRel :  annoBlocksRelList1) {
                    for ( AnnoBlocksRel annoBlocksRel1 : annoBlocksRelList ) {
                        if( annoBlocksRel1.getHousingEstatesId().equals(annoBlocksRel.getHousingEstatesId()) && annoBlocksRel1.getLandListedId().equals(annoBlocksRel.getLandListedId())  ){
                          //  log.info("==============添加地块关联表的数量=========={}",annoBlocksRelList.size());
                            annoBlocksRelList.remove(annoBlocksRel1);
                            break;
                        }
                    }
                }
                if(annoBlocksRelList.size() > 0){
                  //  log.info("添加地块关联表的数量{}",annoBlocksRelList.size());
                    int i = annoBlocksRelMapper.insertAllList(annoBlocksRelList);
                    if(i < 1){
                        throw new BusinessException("添加失败！！");
                    }
                }


            }
        return housingEstatesName;
    }

    /**
     * 添加楼盘信息操作
     * @param housingDefine
     * @return
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public boolean createFromOrigin(HousingDefine housingDefine) {
        if(housingDefine.getHousingEstateId() == null && CollectionUtil.isEmpty(housingDefine.getLandListedId())){
            throw new BusinessException("楼盘id和地块id必填一项");
        }
        if(housingDefine.getHousingEstateId() != null && CollectionUtil.isNotEmpty(housingDefine.getLandListedId())){
            throw new BusinessException("楼盘id和地块id只能填写一项");
        }
        if (null == housingDefine.getBlockId()) {
            throw new BusinessException("楼栋id不能为空！");
        }
        //查询楼栋信息
        BlocksOrigin blocksOrigin = blocksOriginService.getById(housingDefine.getBlockId());
        if (null == blocksOrigin) {
            throw new BusinessException("楼栋id不正确！");
        }
        //判断楼盘id是否为空， 如果为空则用315楼盘名称新建一条楼盘数据
        if (null == housingDefine.getHousingEstateId()) {
            HousingEstates housingEstates = new HousingEstates();
            housingEstates.setName(housingDefine.getHousingEstateName());
            housingEstates.setStatusCd(Constant.COMMON_STATUS_1000);
            this.save(housingEstates);
            housingDefine.setHousingEstateId(housingEstates.getHousingEstateId());//楼盘ID
        }
        //查询楼盘业态是否存在，不存在时新建
            Format format = new Format();
            format.setHousingEstateId(housingDefine.getHousingEstateId());
            format.setPropertyType(housingDefine.getPropertyType());
            format.setLargeFormat(housingDefine.getLargeFormat());
            format.setFormat(housingDefine.getFormat());
            format.setStatusCd(Constant.COMMON_STATUS_1000);
            formatService.save(format);

        //保存楼栋和房屋数据
        copyBlocksOriginToBlocks(blocksOrigin, housingDefine,format.getFormatId());
        //保存楼盘和地块之间的关系
        List<String> landListedIds = housingDefine.getLandListedId();
        List<AnnoBlocksRel> annoBlocksRelList = new ArrayList<>(landListedIds.size());
        for (int i = 0; i < landListedIds.size(); i++) {
            AnnoBlocksRel annoBlocksRel = new AnnoBlocksRel();
            annoBlocksRel.setHousingEstatesId(housingDefine.getHousingEstateId());//楼盘
            annoBlocksRel.setLandListedId(landListedIds.get(i)); //地块
            annoBlocksRel.setStatusCd(Constant.COMMON_STATUS_1000); //状态
            //一个条数据为主要地块
            if (i == 0) {
                annoBlocksRel.setMainLand(1);
            } else {
                annoBlocksRel.setMainLand(0);
            }
            annoBlocksRelList.add(annoBlocksRel);
        }
        annoBlocksRelService.saveBatch(annoBlocksRelList);
        //origin更新为已处理
        blocksOrigin.setStatusCd(BlocksOriginStatusEnum.HANDLED.getCode());
        blocksOrigin.updateById();
        return true;
    }

    @Override
    public HousingEstatesDetail getHousingEstatesDetail(Long housingEstateId) {
        HousingEstatesDetail detail = new HousingEstatesDetail();
        HousingEstates housingEstates = baseMapper.selectById(housingEstateId);
        if (null == housingEstates) {
            return detail;
        }
        detail.setHousingEstates(housingEstates);
        AnnoBlocksRel annoBlocksRel = annoBlocksRelService.getOne(Wrappers.<AnnoBlocksRel>query().lambda()
                .eq(AnnoBlocksRel::getHousingEstatesId, housingEstateId).eq(AnnoBlocksRel::getMainLand, 1));
        if (null != annoBlocksRel) {
            LandListed landListed = landListedMapper.selectOne(Wrappers.<LandListed>lambdaQuery()
                    .eq(LandListed::getLandListedId, annoBlocksRel.getLandListedId()));
            detail.setLandListed(landListed);
        }
        List<Format> format = formatService.list(Wrappers.<Format>lambdaQuery().eq(Format::getHousingEstateId, housingEstateId));
        detail.setFormats(format);
        return detail;
    }

    @Override
    public IPage<HousingEstatesListDto> page(QueryPage page, HousingEstatesQuery query) {
        return baseMapper.selectIPage(page.toPage(), query);
    }

    /**
     * 保存楼栋
     * @param blocksOrigin 楼栋信息
     * @param housingDefine 楼栋数据信息
     * @param formatId 业态信息ID
     */
    private void copyBlocksOriginToBlocks(BlocksOrigin blocksOrigin, HousingDefine housingDefine,Long formatId) {
        Blocks blocks = new Blocks();
        blocks.setHousingEstateId(housingDefine.getHousingEstateId());
        blocks.setFormatId(formatId);
        blocks.setBlockName(blocksOrigin.getBuildingNo());
        blocks.setPreSalePermitNo(blocksOrigin.getPreSaleLicenseNo());
        blocks.setStatusCd(Constant.COMMON_STATUS_1000);
        blocksService.save(blocks);
        copyHousesOriginToHouses(housingDefine.getBlockId(), blocks.getBlockId() ,formatId,blocksOrigin.getPosition() );
    }

    /**
     * 保存房间数据
     * @param originBlockId  楼栋ID
     * @param blockId 楼栋楼盘业态ID
     */
    private void copyHousesOriginToHouses(Long originBlockId, Long blockId,Long formatId,String position) {
        //截取_之前字符串
        String  str1 = position.substring(0, position.indexOf("区")+1);

        boolean b = position.contains("镇");
        if(b){
            str1 = position.substring(0, position.indexOf("镇")+1);
        }
        boolean c = position.contains("路");
        if(c){
            str1 = position.substring(0, position.indexOf("路")+1);
        }
        //截取_之后字符串
        boolean a = position.contains("市");
        if(a){
            String str2 = position.substring(0, position.indexOf("市"));
            str1 = position.substring(str2.length(), position.substring(0, position.indexOf("区")).length()+1);
        }
        log.info("查询房屋的地址为{}",str1);
        List<HousesOrigin> origins = housesOriginService.list(Wrappers.<HousesOrigin>query().lambda()
                .eq(HousesOrigin::getBuildingId, originBlockId)
                .like(HousesOrigin::getHousePosition,str1)
        );//查询和楼栋关联的房间
        if (origins.size() == 0) {
            log.info("没有可复制的HousesOrigin，blockId={}", originBlockId);
            throw  new BusinessException("没有查询到房屋信息");
        }
        List<Houses> housesList = new ArrayList<>(origins.size());
        List<HousesOrigin> housesOriginList = new ArrayList<>(); //
        origins.forEach(housesOrigin -> {
            BigDecimal bigDecimal = new BigDecimal(0);
            //去除不是房间的数据
            if(housesOrigin.getSleevePrice().compareTo(bigDecimal) > 0){
                Houses houses = new Houses();
                houses.setBlockId(blockId);
                houses.setCoveredArea(housesOrigin.getCoveredArea());
                houses.setCoveredPrice(housesOrigin.getCoveredPrice());
                houses.setHouseNo(housesOrigin.getHouseNo());
                houses.setHouseType(housesOrigin.getHouseType());
                houses.setHouseUsage(housesOrigin.getHouseUsage());
                houses.setNetSignDate(housesOrigin.getNetSignDate());
                houses.setNetSignStatus(housesOrigin.getNetSignStatus());
                houses.setSaleStatus(housesOrigin.getSaleStatus());
                houses.setSaleDate(housesOrigin.getSaleDate());
                houses.setSleeveArea(housesOrigin.getSleeveArea());
                houses.setSleevePrice(housesOrigin.getSleevePrice());
                houses.setHouseNo(housesOrigin.getHouseNo());
                houses.setSubscribeStatus(housesOrigin.getSubscribeStatus());
                houses.setSubscribeDate(housesOrigin.getSubscribeDate());
                houses.setUnitNum(housesOrigin.getUnitNum());
                houses.setStatusCd(Constant.COMMON_STATUS_1000);
                housesList.add(houses);
                //计算成交的数量,面积
                if(StrUtil.isNotBlank(housesOrigin.getSubscribeStatus()) || StrUtil.isNotBlank(housesOrigin.getNetSignStatus()) ) {
 //                   log.info("{}==={}",housesOrigin.getSubscribeStatus(),housesOrigin.getNetSignStatus());
                    housesOriginList.add(housesOrigin);
                }

            }

        });
        //添加对应的房间信息
        housesService.saveBatch(housesList);

        //修改业态的套数
        Format format = new Format();
        format.setFormatId(formatId);
        format.setSupplyCount(housesList.size()); //供应总套数
 //       log.info("成交套数==={}",housesOriginList.size());
        format.setDealtCount(housesOriginList.size()); //成交套数
        //已售面积
        BigDecimal bigDecimal = new BigDecimal(0);
        for (HousesOrigin housesOrigin : housesOriginList) { //成交的数量,面积
            bigDecimal =  bigDecimal.add(housesOrigin.getCoveredArea());
        }
        BigDecimal  totalQuantity= new BigDecimal(0);//供给面积
        for (Houses houses : housesList) {
            totalQuantity = totalQuantity.add(houses.getCoveredArea());
        }
        format.setDealtArea(bigDecimal);//成交面积
        format.setSupplyArea(totalQuantity);//供给总面积
        format.setNarrowSenseStock(totalQuantity.subtract(bigDecimal));//狭义库存
        formatService.updateById(format);
    }
}
