package com.air.land.controller;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cinderella.framework.common.core.util.R;
import com.air.land.entity.LandListedConstructionPlan;
import com.air.land.service.LandListedConstructionPlanService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;


/**
 * 已挂牌地块关联建设规划
 *
 * @author peihao
 * @date 2021-06-17 20:07:27
 */
@RestController
@AllArgsConstructor
@RequestMapping("/landlistedconstructionplan")
@Api(value = "landlistedconstructionplan", tags = "已挂牌地块关联建设规划管理")
public class LandListedConstructionPlanController {

    private final  LandListedConstructionPlanService landListedConstructionPlanService;

    /**
     * 分页查询
     * @param page 分页对象
     * @param landListedConstructionPlan 已挂牌地块关联建设规划
     * @return
     */
    @ApiOperation(value = "分页查询", notes = "分页查询")
    @GetMapping("/page")
    public R getLandListedConstructionPlanPage(Page page, LandListedConstructionPlan landListedConstructionPlan) {
        return R.ok(landListedConstructionPlanService.page(page, Wrappers.query(landListedConstructionPlan)));
    }


    /**
     * 通过id查询已挂牌地块关联建设规划
     * @param constructionPlanId id
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/{constructionPlanId}")
    public R getById(@PathVariable("constructionPlanId") Long constructionPlanId) {
        return R.ok(landListedConstructionPlanService.getById(constructionPlanId));
    }

    /**
     * 新增已挂牌地块关联建设规划
     * @param landListedConstructionPlan 已挂牌地块关联建设规划
     * @return R
     */
    @ApiOperation(value = "新增已挂牌地块关联建设规划", notes = "新增已挂牌地块关联建设规划")
    @PostMapping
    public R save(@RequestBody LandListedConstructionPlan landListedConstructionPlan) {
        return R.ok(landListedConstructionPlanService.save(landListedConstructionPlan));
    }

    /**
     * 修改已挂牌地块关联建设规划
     * @param landListedConstructionPlan 已挂牌地块关联建设规划
     * @return R
     */
    @ApiOperation(value = "修改已挂牌地块关联建设规划", notes = "修改已挂牌地块关联建设规划")
    @PutMapping
    public R updateById(@RequestBody LandListedConstructionPlan landListedConstructionPlan) {
        return R.ok(landListedConstructionPlanService.updateById(landListedConstructionPlan));
    }

    /**
     * 通过id删除已挂牌地块关联建设规划
     * @param constructionPlanId id
     * @return R
     */
    @ApiOperation(value = "通过id删除已挂牌地块关联建设规划", notes = "通过id删除已挂牌地块关联建设规划")
    @DeleteMapping("/{constructionPlanId}")
    public R removeById(@PathVariable Long constructionPlanId) {
        return R.ok(landListedConstructionPlanService.removeById(constructionPlanId));
    }
}
