package com.air.land.controller;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import com.air.land.entity.LandListed;
import com.air.land.service.LandListedService;
import com.air.land.vo.LandListedExcelVo;
import com.air.land.vo.LandListedPageVo;
import com.air.land.vo.LandListedVo;
import com.air.utils.DateUtil;
import com.air.utils.ExcelUtil;
import com.air.utils.RedisUtil;
import com.alibaba.excel.EasyExcel;
import com.alibaba.excel.ExcelWriter;
import com.alibaba.excel.write.metadata.WriteSheet;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cinderella.framework.common.core.util.R;
import com.cinderella.framework.common.data.mybatis.QueryPage;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;

import org.apache.poi.sl.usermodel.Sheet;
import org.apache.poi.xssf.streaming.SXSSFWorkbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;

import org.springframework.core.io.ClassPathResource;
import org.springframework.data.redis.connection.jedis.JedisUtils;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

import java.time.LocalDateTime;
import java.util.List;
import java.util.concurrent.TimeUnit;


/**
 * 已挂牌地块。
 *
 * @author peihao
 * @date 2021-05-18 09:39:59
 */
@RestController
@RequestMapping("/landlisted")
@Api(value = "landlisted", tags = "已挂牌地块据管理")
@Slf4j
public class LandListedController {

    @Autowired
    private LandListedService landListedService;

    @Value("${minio.down-url}")
    private String minioDownUrl;

    @Value("${template.land_listed}")
    private String landListedUrl;

    /**
     * 分页查询
     *
     * @param page   分页对象
     * @param pageVo 查询参数
     * @return
     */
    @ApiOperation(value = "分页查询", notes = "分页查询")
    @GetMapping
    public R<Page<LandListed>> getLandListedPage(QueryPage page, LandListedPageVo pageVo) {
        Page<LandListed> result = landListedService.page(page.toPage(), Wrappers.<LandListed>query().lambda()
                //公告序号
                .like(StringUtils.isNotEmpty(pageVo.getAnnoId()), LandListed::getAnnoId, pageVo.getAnnoId())
                //地块编号
                .like(StringUtils.isNotEmpty(pageVo.getLandCode()), LandListed::getLandCode, pageVo.getLandCode())
                //土地用途
                .eq(StringUtils.isNotEmpty(pageVo.getLandUsage()), LandListed::getLandUsage, pageVo.getLandUsage())
                //公告日期
                .eq(ObjectUtil.isNotEmpty(pageVo.getAnnoDate()), LandListed::getAnnoDate, pageVo.getAnnoDate())
                //拍卖日期
                .eq(ObjectUtil.isNotEmpty(pageVo.getAuctionDate()), LandListed::getAuctionDate, pageVo.getAuctionDate())
                //地质灾害
                .eq(StringUtils.isNotEmpty(pageVo.getGeologicHazard()), LandListed::getGeologicHazard, pageVo.getGeologicHazard())
                //人防还建
                .eq(ObjectUtil.isNotEmpty(pageVo.getCivilAirDefence()), LandListed::getCivilAirDefence, pageVo.getCivilAirDefence())
                //特殊规划
                .eq(ObjectUtil.isNotEmpty(pageVo.getSpecialPlan()), LandListed::getSpecialPlan, pageVo.getSpecialPlan())
                //勾地形式
                .eq(StringUtils.isNotEmpty(pageVo.getHookForm()), LandListed::getHookForm, pageVo.getHookForm())
                //勾地企业
                .eq(ObjectUtil.isNotEmpty(pageVo.getLandEnterprises()), LandListed::getLandEnterprises, pageVo.getLandEnterprises())
                //城市
                .eq(ObjectUtil.isNotEmpty(pageVo.getCity()), LandListed::getCity, pageVo.getCity())
                //行政区
                .eq(StringUtils.isNotEmpty(pageVo.getCanton()), LandListed::getCanton, pageVo.getCanton())
                //大组团
                .like(StringUtils.isNotEmpty(pageVo.getBigGroup()), LandListed::getBigGroup, pageVo.getBigGroup())
                //小组团
                .like(StringUtils.isNotEmpty(pageVo.getSmallGroup()), LandListed::getSmallGroup, pageVo.getSmallGroup())
                //受让单位
                .eq(StringUtils.isNotEmpty(pageVo.getAssignee()), LandListed::getAssignee, pageVo.getAssignee())
                //拿地企业
                .eq(ObjectUtil.isNotEmpty(pageVo.getLandEnterpriseShort()), LandListed::getLandEnterpriseShort, pageVo.getLandEnterpriseShort())
                //参拍企业
                .eq(ObjectUtil.isNotEmpty(pageVo.getParticipatingEnterprises()), LandListed::getParticipatingEnterprises, pageVo.getParticipatingEnterprises())
                //项目状态
                .eq(StringUtils.isNotEmpty(pageVo.getProjectStatus()), LandListed::getProjectStatus, pageVo.getProjectStatus())
                //楼盘名称
                .eq(ObjectUtil.isNotEmpty(pageVo.getBuildingName()), LandListed::getBuildingName, pageVo.getBuildingName())
                //操盘企业
                .eq(ObjectUtil.isNotEmpty(pageVo.getTradingEnterprises()), LandListed::getTradingEnterprises, pageVo.getTradingEnterprises())
                //经营企业
                .eq(StringUtils.isNotEmpty(pageVo.getConductEnterprise()), LandListed::getConductEnterprise, pageVo.getConductEnterprise())
                .eq(StringUtils.isNotEmpty(pageVo.getSystemId()), LandListed::getSystemId, pageVo.getSystemId())
                .orderByDesc(LandListed::getLandListedId));
        return R.ok(result, "查询成功");
    }

    /**
     * 通过id查询已挂牌地块
     *
     * @param landListedId
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/{landListedId}")
    public R<LandListed> getById(@PathVariable("landListedId") String landListedId) {
        return R.ok(landListedService.getById(landListedId));
    }

    /**
     * 保存已挂牌地块
     *
     * @param landListedVo 已挂牌地块参数
     * @return R
     */
    @ApiOperation(value = "新增已挂牌地块", notes = "新增已挂牌地块")
    @PostMapping
    public R<String> saveLandListed(@RequestBody LandListedVo landListedVo) {
        LandListed landListed = new LandListed();
        BeanUtil.copyProperties(landListedVo, landListed);
        landListed.setLandListedId(DateUtil.landListedIdfromDate(LocalDateTime.now(), "yyyyMMdd", landListedService.selectId()));
        landListedService.save(landListed);
        return R.ok(landListed.getLandListedId());
    }

    /**
     * 修改已挂牌地块
     *
     * @param landListedVo 已挂牌地块参数
     * @return R
     */
    @ApiOperation(value = "修改已挂牌地块", notes = "修改已挂牌地块")
    @PutMapping
    public R<Boolean> updateLandListed(@RequestBody LandListedVo landListedVo) {
        LandListed landListed = new LandListed();
        BeanUtil.copyProperties(landListedVo, landListed);
        return R.ok(landListedService.updateById(landListed));
    }

    /**
     * 通过id删除已挂牌地块。
     *
     * @param landListedIds id列表
     * @return R
     */
    @ApiOperation(value = "通过id删除已挂牌地块", notes = "通过id删除已挂牌地块")
    @DeleteMapping
    public R removeByIds(@RequestBody List<String> landListedIds) {
        return R.ok(landListedService.removeLandByIds(landListedIds), "删除成功");
    }

    /**
     * 新增信息校验公告序号是否存在
     *
     * @param annoId 公告序号
     * @return
     * @author peihao
     * @date 2021/5/21
     **/
    @ApiOperation(value = "新增信息校验公告序号是否存在", notes = "参入为公告序号")
    @GetMapping("/annoIdValiated/{annoId}")
    public R removeById(@PathVariable String annoId) {
        if (null != landListedService.getById(annoId)) {
            R.failed("公告序号已存在！");
        }
        return R.ok();
    }

    /**
     * 导入已挂牌地块信息
     *
     * @author peihao
     * @date 2021/5/25
     **/
    @ApiOperation(value = "导入已挂牌地块信息", notes = "导入已挂牌地块信息")
    @PostMapping(value = "/importLandListExcel")
    public R importLandListExcel(@RequestParam(value = "uploadFile") MultipartFile file) {
        return R.ok(landListedService.importLandListExcel(file), "导入成功");
    }

    /**
     * 导出已挂牌地块信息
     *
     * @author peihao
     * @date 2021/5/25
     **/
    @ApiOperation(value = "导出已挂牌地块信息", notes = "导出已挂牌地块信息")
    @GetMapping("/exportLandListExcel")
    public void exportLandListExcel(HttpServletResponse response, @RequestParam List<String> ids) throws IOException {
        List<List<String>> landList = landListedService.getLandList(ids);
        InputStream resourceAsStream = LandListedController.class.getClassLoader().getResourceAsStream("templates/excel/exportLandList.xlsx");
        // 读取excel模板
        XSSFWorkbook wb = ExcelUtil.exportLandListedExcel(landList, resourceAsStream, 2);
        response.setContentType("application/vnd.ms-excel;charset=utf-8");
        response.setHeader("Content-Disposition", "attachment;filename=report.xlsx");
        OutputStream outputStream = response.getOutputStream();
        wb.write(outputStream);
    }

    /**
     * 下载已挂牌地块模板
     *
     * @return R
     */
    @ApiOperation(value = "下载已挂牌地块模板", notes = "下载已挂牌地块模板")
    @GetMapping("/getTemplate")
    public R<String> getLandListedTemplate() {
        return R.ok(minioDownUrl + landListedUrl);
    }


    /**
     * 导出已挂牌地块信息
     *
     * @author peihao
     * @date 2021/5/25
     **/
    @ApiOperation(value = "导出全部已挂牌地块信息", notes = "导出全部已挂牌地块信息")
    @GetMapping("/exportAllLandListExcels")
    public void exportAllLandListExcel(HttpServletResponse response) throws IOException {
//        if(redisUtil.getCacheObject("/exportAllLandListExcel/wb") != null){
////            OutputStream outputStream = new ByteArrayOutputStream();
//            XSSFWorkbook wb = redisUtil.getCacheObject("/exportAllLandListExcel/wb");
//            response.setContentType("application/vnd.ms-excel;charset=utf-8");
//            response.setHeader("Content-Disposition", "attachment;filename=report.xlsx");
//            OutputStream outputStream = response.getOutputStream();
//            wb.write(outputStream);
//        }else{
//            List<List<String>> landList = landListedService.getLandList(null);
//            InputStream resourceAsStream = LandListedController.class.getClassLoader().getResourceAsStream("templates/excel/exportLandList.xlsx");
//            // 读取excel模板
//                XSSFWorkbook wb = ExcelUtil.exportLandListedExcel(landList, resourceAsStream, 2);
//                response.setContentType("application/vnd.ms-excel;charset=utf-8");
//                response.setHeader("Content-Disposition", "attachment;filename=report.xlsx");
//                OutputStream outputStream = response.getOutputStream();
//                wb.write(outputStream);
//        }
        List<List<String>> landList = landListedService.getLandList(null);
        InputStream resourceAsStream = LandListedController.class.getClassLoader().getResourceAsStream("templates/excel/exportLandList.xlsx");
        //获取静态文件
//        ClassPathResource classPathResource = new ClassPathResource("templates/excel/exportLandList.xlsx");
//        InputStream inputStream = classPathResource.getInputStream();
//        InputStream resourceAsStream = LandListedController.class.getClassLoader().getResourceAsStream("templates/excel/exportLandList.xlsx");
        // 读取excel模板
        XSSFWorkbook wb = null;
        OutputStream outputStream = new ByteArrayOutputStream();
        try {
            log.info("开始时间" + System.currentTimeMillis());
            wb = ExcelUtil.exportLandListedExcel(landList, resourceAsStream, 2);
            response.setContentType("application/vnd.ms-excel;charset=utf-8");
            response.setHeader("Content-Disposition", "attachment;filename=report.xlsx");
            outputStream = response.getOutputStream();
            wb.write(outputStream);
            log.info("结束时间" + System.currentTimeMillis());
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            try {
                if (outputStream != null) {
                    outputStream.close();
                }
                if (wb != null) {
                    wb.close();
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
        }

    }


    /**
     * 导出已挂牌地块信息
     *
     * @author peihao
     * @date 2021/5/25
     **/
    @ApiOperation(value = "导出全部已挂牌地块信息", notes = "导出全部已挂牌地块信息")
    @GetMapping("/exportAllLandListExcel")
    public void exportAllLandListExcels(HttpServletResponse response,String city)  {
        log.info("====地区{}",city);
        int NUM_PER_SHEET = 300000;
        // 每次向 sheet 中写入的数据（分页写入）
        int NUM_BY_TIMES = 50000;

        long startTime = System.currentTimeMillis();
        response.setContentType("application/vnd.ms-excel;charset=utf-8");
        response.setHeader("Content-Disposition", "attachment;filename=report.xlsx");

//        OutputStream stream = null;
//        try {
//            stream = response.getOutputStream();
//            stream.write(city.getBytes("UTF-8"));
//        } catch (IOException e) {
//            e.printStackTrace();
//        }
        // 获取数据
        List<List<String>> date = landListedService.getLandListCity(city);
//        List<List<String>> date = landListedService.getLandList(null);
        log.info(date.size() + "==================================多少数量");
 //       InputStream resourceAsStream = LandListedController.class.getClassLoader().getResourceAsStream("templates/excel/exportLandList.xlsx");
        //获取静态文件
        ClassPathResource classPathResource = new ClassPathResource("templates/excel/excelAllLand.xlsx");
        InputStream inputStream = null;
        try {
            inputStream = classPathResource.getInputStream();
        } catch (IOException e) {
            e.printStackTrace();
        }
        // 获取 sheet 的个数
        int sheetNum = date.size() % NUM_PER_SHEET == 0 ? date.size() / NUM_PER_SHEET : date.size() / NUM_PER_SHEET + 1;
        log.info("sheetNum===============================" + sheetNum);

        // 指定写入的文件  //ExcelWriter该对象用于通过POI将值写入Excel
        ExcelWriter excelWriter = null;
        try {
            excelWriter = EasyExcel.write(response.getOutputStream()).withTemplate(inputStream)
                    //设置默认样式及写入头信息开始的行数
                    //.useDefaultStyle(true).relativeHeadRowIndex(3)
                    .build();
            for (int i = 0; i < sheetNum; i++) {
                long l = System.currentTimeMillis();
                // 设置 sheet 的名字（sheet不能相同）
                String sheetName = "sheet" + i;
                WriteSheet writeSheet = EasyExcel.writerSheet(i, sheetName).build();
                //WriteSheet writeSheet = EasyExcel.writerSheet().build();
                //WriteSheet writeSheet1 = EasyExcel.writerSheet().registerWriteHandler(new MyHandler()).build();
                int startNum = i * NUM_PER_SHEET;
                int endNum = i == sheetNum - 1 ? date.size() : (i + 1) * NUM_PER_SHEET;
                excelWriter.write(date.subList(startNum, endNum), writeSheet);
                log.info("写入sheet={}，数据量{}-{}={}，耗时={}ms", sheetName, endNum, startNum, endNum - startNum, System.currentTimeMillis() - l);
                //  excelWriter.fill(date.subList(startNum, endNum), writeSheet);
                // excelWriter.fill(date, writeSheet);
            }
        } catch (IOException e) {
            e.printStackTrace();
        }finally{
            // 最好放在 finally中
            excelWriter.finish();
            log.info("导出excel结束,总数据量={}，耗时={}ms", date.size(), System.currentTimeMillis() - startTime);
        }

    }

}



































