package com.air.land.controller;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cinderella.framework.common.core.util.R;
import com.air.land.entity.LandToListConductEnterprise;
import com.air.land.service.LandToListConductEnterpriseService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;


/**
 * 拟挂牌地块关联经营企业
 *
 * @author peihao
 * @date 2021-06-17 20:07:43
 */
@RestController
@AllArgsConstructor
@RequestMapping("/landtolistconductenterprise")
@Api(value = "landtolistconductenterprise", tags = "拟挂牌地块关联经营企业管理")
public class LandToListConductEnterpriseController {

    private final  LandToListConductEnterpriseService landToListConductEnterpriseService;

    /**
     * 分页查询
     * @param page 分页对象
     * @param landToListConductEnterprise 拟挂牌地块关联经营企业
     * @return
     */
    @ApiOperation(value = "分页查询", notes = "分页查询")
    @GetMapping("/page")
    public R getLandToListConductEnterprisePage(Page page, LandToListConductEnterprise landToListConductEnterprise) {
        return R.ok(landToListConductEnterpriseService.page(page, Wrappers.query(landToListConductEnterprise)));
    }


    /**
     * 通过id查询拟挂牌地块关联经营企业
     * @param conductEnterpriseId id
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/{conductEnterpriseId}")
    public R getById(@PathVariable("conductEnterpriseId") Long conductEnterpriseId) {
        return R.ok(landToListConductEnterpriseService.getById(conductEnterpriseId));
    }

    /**
     * 新增拟挂牌地块关联经营企业
     * @param landToListConductEnterprise 拟挂牌地块关联经营企业
     * @return R
     */
    @ApiOperation(value = "新增拟挂牌地块关联经营企业", notes = "新增拟挂牌地块关联经营企业")
    @PostMapping
    public R save(@RequestBody LandToListConductEnterprise landToListConductEnterprise) {
        return R.ok(landToListConductEnterpriseService.save(landToListConductEnterprise));
    }

    /**
     * 修改拟挂牌地块关联经营企业
     * @param landToListConductEnterprise 拟挂牌地块关联经营企业
     * @return R
     */
    @ApiOperation(value = "修改拟挂牌地块关联经营企业", notes = "修改拟挂牌地块关联经营企业")
    @PutMapping
    public R updateById(@RequestBody LandToListConductEnterprise landToListConductEnterprise) {
        return R.ok(landToListConductEnterpriseService.updateById(landToListConductEnterprise));
    }

    /**
     * 通过id删除拟挂牌地块关联经营企业
     * @param conductEnterpriseId id
     * @return R
     */
    @ApiOperation(value = "通过id删除拟挂牌地块关联经营企业", notes = "通过id删除拟挂牌地块关联经营企业")
    @DeleteMapping("/{conductEnterpriseId}")
    public R removeById(@PathVariable Long conductEnterpriseId) {
        return R.ok(landToListConductEnterpriseService.removeById(conductEnterpriseId));
    }
}
