package com.air.land.controller;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import com.air.common.Constant;
import com.air.land.entity.LandToList;
import com.air.land.service.LandToListSendService;
import com.air.land.service.LandToListService;

import com.air.land.vo.LandToListPageVo;
import com.air.land.vo.LandToListVo;
import com.air.utils.DateUtil;
import com.air.utils.ExcelUtil;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cinderella.framework.common.core.util.R;
import com.cinderella.framework.common.data.mybatis.QueryPage;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.time.LocalDateTime;
import java.util.List;


/**
 * 拟挂牌地块
 *
 * @author peihao
 * @date 2021-05-18 09:40:09
 */
@RestController
@RequestMapping("/landtolist")
@Api(value = "landtolist", tags = "拟挂牌地块管理")
public class LandToListController {

    @Autowired
    private LandToListService landToListService;

    @Autowired
    private LandToListSendService landToListSendService;

    @Value("${minio.down-url}")
    private String minioDownUrl;

    @Value("${template.land_to_listed}")
    private String landToListedUrl;


    /**
     * 分页查询
     *
     * @param page   分页对象
     * @param pageVo 拟挂牌地块。
     * @return
     */
    @ApiOperation(value = "分页查询", notes = "分页查询")
    @GetMapping
    public R<Page<LandToList>> getLandToListPage(QueryPage page, LandToListPageVo pageVo) {
        Page<LandToList> result = landToListService.page(page.toPage(), Wrappers.<LandToList>query().lambda()
                //供地状态
                .eq(StringUtils.isNotEmpty(pageVo.getSupplyStatus()), LandToList::getSupplyStatus, pageVo.getSupplyStatus())
                //预计挂牌时间
                .eq(StringUtils.isNotEmpty(pageVo.getEstimatedListingTime()), LandToList::getEstimatedListingTime, pageVo.getEstimatedListingTime())
                //地块编号
                .eq(StringUtils.isNotEmpty(pageVo.getLandCode()), LandToList::getLandCode, pageVo.getLandCode())
                //土地用途
                .eq(StringUtils.isNotEmpty(pageVo.getLandUsage()), LandToList::getLandUsage, pageVo.getLandUsage())
                //地质灾害
                .eq(ObjectUtil.isNotEmpty(pageVo.getGeologicHazard()), LandToList::getGeologicHazard, pageVo.getGeologicHazard())
                //人防还建
                .eq(ObjectUtil.isNotEmpty(pageVo.getCivilAirDefence()), LandToList::getCivilAirDefence, pageVo.getCivilAirDefence())
                //特殊规划
                .eq(StringUtils.isNotEmpty(pageVo.getSpecialPlan()), LandToList::getSpecialPlan, pageVo.getSpecialPlan())
                //勾地形式
                .eq(StringUtils.isNotEmpty(pageVo.getHookForm()), LandToList::getHookForm, pageVo.getHookForm())
                //勾地企业
                .eq(StringUtils.isNotEmpty(pageVo.getLandEnterprises()), LandToList::getLandEnterprises, pageVo.getLandEnterprises())
                //出让人
                .eq(StringUtils.isNotEmpty(pageVo.getBargainor()), LandToList::getBargainor, pageVo.getBargainor())
                //城市
                .eq(StringUtils.isNotEmpty(pageVo.getCity()), LandToList::getCity, pageVo.getCity())
                //行政区
                .eq(StringUtils.isNotEmpty(pageVo.getCanton()), LandToList::getCanton, pageVo.getCanton())
                //大组团
                .like(StringUtils.isNotEmpty(pageVo.getBigGroup()), LandToList::getBigGroup, pageVo.getBigGroup())
                //小组团
                .like(StringUtils.isNotEmpty(pageVo.getSmallGroup()), LandToList::getSmallGroup, pageVo.getSmallGroup())
                .orderByDesc(LandToList::getProposedseriaId));
        return R.ok(result, "查询成功");
    }


    /**
     * 通过id查询拟挂牌地块。
     *
     * @param id
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/{id}")
    public R<LandToList> getById(@PathVariable("id") String id) {
        return R.ok(landToListService.getById(id));
    }

    /**
     * 新增拟挂牌地块
     *
     * @param landToListVo 拟挂牌地块
     * @return R
     */
    @ApiOperation(value = "新增拟挂牌地块", notes = "新增拟挂牌地块")
    @PostMapping
    public R addlandToList(@RequestBody LandToListVo landToListVo) {
        LandToList landToList = new LandToList();
        BeanUtil.copyProperties(landToListVo, landToList);
        landToList.setProposedseriaId(DateUtil.landToListIdfromDate(LocalDateTime.now(),"yyyyMMdd",landToListService.selectId()));
        landToList.setStatusCd(Constant.LAND_TO_STATUS_1000);
        landToListService.save(landToList);
        return R.ok(landToList.getProposedseriaId());
    }

    /**
     * 修改拟挂牌地块
     *
     * @param landToListVo 拟挂牌地块
     * @return R
     */
    @ApiOperation(value = "修改拟挂牌地块", notes = "修改拟挂牌地块")
    @PutMapping
    public R updatelandToList(@RequestBody LandToListVo landToListVo) {
        if (StringUtils.isEmpty(landToListVo.getProposedseriaId())){
            return R.failed("id不能为空");
        }
        LandToList landToList = new LandToList();
        BeanUtil.copyProperties(landToListVo, landToList);
        return R.ok(landToListService.updateById(landToList));
    }

    /**
     * 通过id删除拟挂牌地块。
     *
     * @param proposedseriaIds id列表
     * @return R
     */
    @ApiOperation(value = "通过id删除拟挂牌地块", notes = "通过id删除拟挂牌地块")
    @DeleteMapping
    public R removeById(@RequestBody List<String> proposedseriaIds) {
        return R.ok(landToListService.removeLandToListByIds(proposedseriaIds));
    }


    /**
     * 发送到已挂牌
     *
     * @param proposedseriaId 拟挂牌数据id
     * @return R
     */
    @ApiOperation(value = "发送到已挂牌", notes = "发送到已挂牌")
    @PostMapping("/sendLandList")
    public R<Boolean> sendLandList(@RequestParam String proposedseriaId) {
        return landToListSendService.landToListSendLandListed(proposedseriaId);
    }

    /**
     * 导入拟挂牌地块信息
     * @author peihao
     * @date 2021/5/25
     **/
    @ApiOperation(value = "导入拟挂牌地块信息", notes = "导入拟挂牌地块信息")
    @PostMapping(value = "/importLandToListExcel")
    public R importLandToListExcel(@RequestParam(value="uploadFile") MultipartFile file){
        return R.ok(landToListService.importLandToListExcel(file),"导入成功");
    }


    /**
     * 导出拟挂牌地块信息
     * @author peihao
     * @date 2021/5/25
     **/
    @ApiOperation(value = "导出拟挂牌地块信息",notes = "导出拟挂牌地块信息")
    @GetMapping("/exportLandToListExcel")
    public void exportLandToListExcel(HttpServletResponse response, @RequestParam List<String> ids) throws IOException {
        List<List<String>> landList = landToListService.getLandList(ids);
        InputStream resourceAsStream = LandListedController.class.getClassLoader().getResourceAsStream("templates/excel/exportLandToList.xlsx");
        // 读取excel模板
//        XSSFWorkbook wb = ExcelExportUtil.exportLandListedExcel(landList,resourceAsStream,2);
        XSSFWorkbook wb = ExcelUtil.exportLandListedExcel(landList,resourceAsStream,2);
        response.setContentType("application/vnd.ms-excel;charset=utf-8");
        response.setHeader("Content-Disposition","attachment;filename=report.xlsx");
        OutputStream outputStream = response.getOutputStream();
        wb.write(outputStream);
    }

    /**
     * 下载已挂牌地块模板
     *
     * @return R
     */
    @ApiOperation(value = "下载已挂牌地块模板", notes = "下载已挂牌地块模板")
    @GetMapping("/getTemplate")
    public R<String> getLandListedTemplate() {
        return R.ok(minioDownUrl+landToListedUrl);
    }
}
