package com.air.land.mapper;

import com.air.applets.dto.LandDto;
import com.air.applets.vo.LandVo;
import com.air.land.dto.LandListedDto;
import com.air.land.dto.LandListedStatisticsDto;
import com.air.land.entity.LandListed;
import com.air.land.vo.LandListedAppletsVo;
import com.baomidou.mybatisplus.annotation.SqlParser;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;

import java.util.List;

/**
 * 已挂牌地块，整体数据的核心，数据来源三部分：爬虫数据、用户维护数据、系统计算数据。
 *
 * @author peihao
 * @date 2021-05-18 09:39:59
 */
public interface LandListedMapper extends BaseMapper<LandListed> {

    List<LandListedDto> getLandListedByDate(Page page, @Param("param") LandListedAppletsVo appletsVo);

    /**
     * 按日期统计地块数量
     * @author peihao
     * @param appletsVo 统计参数
     * @date 2021/7/9
     * @return
     **/
    Integer statisticsListedCount(@Param("param") LandListedAppletsVo appletsVo);

    /**
     * 复合条件查询已挂牌列表数据
     * @author peihao
     * @param page 分页对象
     * @param landVo 查询参数
     * @date 2021/7/9
     * @return
     **/
    List<LandDto> appletsLandListed(Page page , @Param("landVo")LandVo landVo);


    /**
     * 按挂牌日期统计地块数量(日历)
     * @author peihao
     * @param annoDate 挂牌日期(yyyy-MM）
     * @param city 城市
     * @param canton 区县
     * @date 2021/7/9
     * @return
     **/
    List<LandListedStatisticsDto> appletsCalendarToAnnoDate(@Param("annoDate") String annoDate , @Param("city") String city,@Param("canton") String canton);

    /**
     * 按拍卖日期统计地块数量(日历)
     * @author peihao
     * @param auctionDate 拍卖日期(yyyy-MM）
     * @param city 城市
     * @param canton 区县
     * @date 2021/7/9
     * @return
     **/
    List<LandListedStatisticsDto> appletsCalendarToAuctionDate(@Param("auctionDate") String auctionDate , @Param("city") String city,@Param("canton") String canton);

    /**
     * 获取序列
     * @author peihao
     * @date 2021/8/16
     * @return
     **/
    @SqlParser(filter = true)
    @Select("select nextval('land_list_id')")
    Integer selectId();


    /**
     * 查询已挂牌地库楼盘名称
     */
    List<LandListed> selectBuildingName();
    /**
     * 查询已挂牌地库楼盘名称
     */
    List<LandListed> selectBuildingNames();

}
