package com.air.land.service;

import com.air.applets.dto.LandDto;
import com.air.applets.vo.LandVo;
import com.air.land.dto.LandListedDto;
import com.air.land.dto.LandListedStatisticsDto;
import com.air.land.entity.LandListed;
import com.air.land.vo.LandListedAppletsVo;
import com.air.land.vo.LandListedVo;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.IService;
import com.cinderella.framework.common.core.util.R;
import com.cinderella.framework.common.data.mybatis.QueryPage;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;

/**
 * 已挂牌地块，整体数据的核心，数据来源三部分：爬虫数据、用户维护数据、系统计算数据。
 *
 * @author peihao
 * @date 2021-05-18 09:39:59
 */
public interface LandListedService extends IService<LandListed> {

    R<Page<LandListedDto>> getLandListedByDate(QueryPage page, LandListedAppletsVo appletsVo);

    /**
     * 按日期统计地块数量
     * @author peihao
     * @param appletsVo 统计参数
     * @date 2021/7/9
     * @return
     **/
    R<LandListedStatisticsDto> appletsStatistics(LandListedAppletsVo appletsVo);

    /**
     * 按日期统计地块数量
     * @author peihao
     * @param date 日期(yyyy-MM）
     * @param city 城市
     * @param canton 区县
     * @date 2021/7/9
     * @return
     **/
    R<List<LandListedStatisticsDto>> appletsCalendar(String date , String city,String canton);

    /**
     * 导入已挂牌地块信息
     * @author peihao
     * @param file 文件
     * @date 2021/7/9
     * @return
     **/
    boolean importLandListExcel(MultipartFile file);

    /**
     * 通过id查询已挂牌地块数据
     * @author peihao
     * @param ids 已挂牌id集合
     * @date 2021/7/9
     * @return
     **/
    List<List<String>> getLandList(List<String> ids);

    /**
     * 通过地区查询已挂牌地块数据
     * @author peihao
     * @param city 地区导出全部数据
     * @date 2021/7/9
     * @return
     **/
    List<List<String>> getLandListCity(String city);

    /**
     * 复合条件查询已挂牌列表数据
     * @author peihao
     * @param page 分页对象
     * @param landVo 查询参数
     * @date 2021/7/9
     * @return
     **/
    List<LandDto> appletsLandListed(Page page , LandVo landVo);


    /**
     * 获取序列
     * @author peihao
     * @date 2021/8/16
     * @return
     **/
    Integer selectId();


    /**
     * 删除已挂牌地块及经纬度数据
     * @author peihao
     * @param landListedIds 已挂牌id集合
     * @date 2021/9/1
     * @return
     **/
    boolean removeLandByIds(List<String> landListedIds);
}
