package com.air.land.service.impl;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.io.FileUtil;
import cn.hutool.core.io.IoUtil;
import cn.hutool.core.util.RandomUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.core.util.ZipUtil;
import cn.hutool.json.JSONUtil;
import com.air.land.entity.AuctionRecord;
import com.air.land.mapper.AuctionRecordMapper;
import com.air.land.service.AuctionRecordService;
import com.air.land.vo.AuctionRecordPageVo;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cinderella.framework.common.core.exception.BusinessException;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.apache.poi.xssf.usermodel.XSSFCell;
import org.apache.poi.xssf.usermodel.XSSFRow;
import org.apache.poi.xssf.usermodel.XSSFSheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.io.*;
import java.util.ArrayList;
import java.util.List;
import java.util.Objects;

/**
 * 参拍记录表
 *
 * @author peihao
 * @date 2021-05-18 09:39:41
 */
@Service
@Slf4j
public class AuctionRecordServiceImpl extends ServiceImpl<AuctionRecordMapper, AuctionRecord> implements AuctionRecordService {

    @Override
    public void importRecordExcel(MultipartFile file) {
        String tempPath = RandomUtil.randomString(6);
        File dir = FileUtil.mkdir(tempPath);
        File tempFile = FileUtil.createTempFile("record-", "tmp", dir, true);
        try {
            IoUtil.copy(file.getInputStream(), new FileOutputStream(tempFile));
        } catch (IOException e) {
            e.printStackTrace();
        }
        File zipFile = new File(dir.getPath() + "/record.zip");
        FileUtil.move(tempFile, zipFile, true);
        ZipUtil.unzip(zipFile);

        List<File> files = new ArrayList<>();
        getAllDirFiles(dir, files);
        files.forEach(f -> {
            if (!f.getName().startsWith(StrUtil.DOT) && f.getName().endsWith(".xlsx")) {
                log.info(f.getName());
                List<AuctionRecord> lists = null;
                try {
                    lists = readAuction(new FileInputStream(f), 0, 7, 21);
                } catch (IOException e) {
                    e.printStackTrace();
                }
                System.out.println(JSONUtil.toJsonPrettyStr(lists));
            }
        });
        dir.delete();
    }

    @Override
    @SneakyThrows
    public List<AuctionRecord> readRecordExcel(MultipartFile file) {
        return readAuction(file.getInputStream(), 0, 6, 21);
    }

    @Override
    public List<List<String>> getAuctionRecord(List<Long> auctionRecordIds) {
        List<AuctionRecord> auctionRecords = baseMapper.getAuctionRecords(auctionRecordIds);
        if (CollectionUtil.isEmpty(auctionRecords)){
           throw new BusinessException("未查询到企业参拍记录");
        }
        return entityToList(auctionRecords);
    }

    @Override
    public IPage<AuctionRecord> selectPage(Page page, AuctionRecordPageVo recordPageVo) {
        List<AuctionRecord> auctionRecords = baseMapper.selectPages(page, recordPageVo);
        return page.setRecords(auctionRecords);
    }

    private void getAllDirFiles(File file, List<File> files) {
        for (File f : Objects.requireNonNull(file.listFiles())) {
            if (f.isDirectory()) {
                getAllDirFiles(f, files);
            } else {
                files.add(f);
            }
        }
    }


    /**
     * 导入土地参拍记录
     * @author peihao
     * @param file 解析文件
     * @param startSheet 开始sheet
     * @param startRow 开始行
     * @param startCell 开始列
     * @date 2021/12/9
     * @return
     **/
    private List<AuctionRecord> readAuction(InputStream file, int startSheet, int startRow, int startCell) throws IOException {
        // 读取excel模板
        XSSFWorkbook wb = new XSSFWorkbook(file);
        XSSFSheet sheet = wb.getSheetAt(startSheet);
        int rowSum = sheet.getPhysicalNumberOfRows();
        //取值
        String city = sheet.getRow(2).getCell(1).toString();
        String landName = sheet.getRow(0).getCell(0).toString();
        String landCode = sheet.getRow(2).getCell(2).getRawValue();
        String date = DateUtil.formatDate(sheet.getRow(2).getCell(10).getDateCellValue());
        String winnerEnterprise = getCellValue(sheet.getRow(startCell).getCell(startCell + 1));
        //获取数据
        List<AuctionRecord> result = new ArrayList<>();
        int count = 0;
        for (int i = startRow; i < rowSum; i++) {
            XSSFRow sheetRow = sheet.getRow(i);
            String rank = getCellValue(sheetRow.getCell(startCell));
            if (StrUtil.isBlank(rank)) {
                break;
            }
            AuctionRecord record = new AuctionRecord().setCity(city).setLandName(landName).setWinnerEnterprises(winnerEnterprise);
            //排名
            record.setRanking(rank);
            record.setSort(count);
            setAuctionRecord(record,sheetRow,startCell,count);
            result.add(record);
            count++;
        }
        return result;
    }


    /**
     * 解析一行的数据
     * @author peihao
     * @param record 参拍记录对象
     * @param sheetRow 行
     * @param startCell 开始列
     * @param count 判断是否为第一行，特殊处理
     * @date 2021/12/9
     * @return
     **/
    private void setAuctionRecord(AuctionRecord record,XSSFRow sheetRow,int startCell,int count){
        if (count == 0){
            //举牌企业
            record.setRaiseEnterprise(getStringValue(sheetRow.getCell(startCell + 1)));
            //举牌价
            record.setRaisePrice(getStringValue(sheetRow.getCell(startCell + 2)));
            //名义楼面价
            record.setNominalFloorPrice(getStringValue(sheetRow.getCell(startCell + 3)));
            //无偿移交比例
            record.setPercentUnpaidTransfers(getStringValue(sheetRow.getCell(startCell + 4)));
            //实际楼面价
            record.setActualFloorPrice(getStringValue(sheetRow.getCell(startCell + 5)));
            //溢价率
            record.setPremiumRate(getStringValue(sheetRow.getCell(startCell + 6)));
            //最后轮次
            record.setFinalRound(getStringValue(sheetRow.getCell(startCell + 7)));
        }else {
            //举牌企业
            record.setRaiseEnterprise(getCellValue(sheetRow.getCell(startCell + 1)));
            //举牌价
            record.setRaisePrice(getCellPrice(sheetRow.getCell(startCell + 2)));
            //名义楼面价
            record.setNominalFloorPrice(getCellPrice(sheetRow.getCell(startCell + 3)));
            //无偿移交比例
            record.setPercentUnpaidTransfers(getCellPercent(sheetRow.getCell(startCell + 4)));
            //实际楼面价
            record.setActualFloorPrice(getCellPrice(sheetRow.getCell(startCell + 5)));
            //溢价率
            record.setPremiumRate(getCellPercent(sheetRow.getCell(startCell + 6)));
            //最后轮次
            record.setFinalRound(getCellValue(sheetRow.getCell(startCell + 7)));
        }
    }

    private List<List<String>> entityToList(List<AuctionRecord> auctionRecords){
        List<List<String>> result = new ArrayList<>(auctionRecords.size());
        auctionRecords.forEach(auctionRecord -> {
            List<String> list = new ArrayList<>();
            list.add(auctionRecord.getLandCode());
            list.add(auctionRecord.getRanking().toString());
            list.add(auctionRecord.getRaiseEnterprise());
            list.add(auctionRecord.getRaisePrice());
            list.add(auctionRecord.getNominalFloorPrice());
            list.add(auctionRecord.getPercentUnpaidTransfers());
            list.add(auctionRecord.getActualFloorPrice());
            list.add(auctionRecord.getPremiumRate());
            list.add(auctionRecord.getFinalRound());
            list.add(auctionRecord.getWinnerEnterprises());
            result.add(list);
        });
        return result;
    }

    private String getCellValue(XSSFCell cell) {
        String value;
        try {
            cell.getCellFormula();
            value = cell.getRawValue();
        } catch (IllegalStateException e){
            value = cell.toString();
        }
        return value;
    }

    private String getCellPrice(XSSFCell cell) {
        String price = getCellValue(cell);
        if ("未举牌".equals(price)) {
            return price;
        }
        return String.format("%.0f", Double.valueOf(price));
    }

    private String getCellPercent(XSSFCell cell) {
        String percent = getCellValue(cell);
        if ("未举牌".equals(percent)) {
            return percent;
        }
        Double d = Double.valueOf(percent);
        d = d * 100;
        return String.format("%.2f", d);
    }

    private String getStringValue(XSSFCell cell) {
        String cellValue = null;
        try {
            cellValue = cell.getStringCellValue();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return cellValue;
    }
}
