package com.air.land.service.impl;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import com.air.applets.convert.LandLonLatConvert;
import com.air.applets.dto.LandLonLatDto;
import com.air.land.entity.LandListed;
import com.air.land.entity.LandListedLonLat;
import com.air.land.entity.LandToListLonLat;
import com.air.land.mapper.LandListedLonLatMapper;
import com.air.land.service.LandListedLonLatService;
import com.air.utils.DateUtil;
import com.air.utils.ExcelUtil;
import com.air.utils.WgsUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cinderella.framework.common.core.exception.BusinessException;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

/**
 * 已挂牌地块经纬度
 *
 * @author peihao
 * @date 2021-05-18 09:40:04
 */
@Service
public class LandListedLonLatServiceImpl extends ServiceImpl<LandListedLonLatMapper, LandListedLonLat> implements LandListedLonLatService {

    @Override
    public boolean importLandListedLonLatExcel(MultipartFile file,String landListedId) {
        List<List<String>> dataList;
        try{
            dataList = ExcelUtil.importExcel(file,0,1,0);
        }catch (IOException e){
            throw new BusinessException("导入已挂牌经纬度数据出错");
        }
        if (CollectionUtil.isNotEmpty(dataList)){
            List<LandListedLonLat> list = listToEntity(dataList,landListedId);
            return this.saveBatch(list);
        }
        return false;
    }

    @Override
    public List<LandLonLatDto> getLandListedLonLat(String landListedId) {
        List<LandListedLonLat> list = baseMapper.getLandListedLonLat(landListedId);
        return LandLonLatConvert.getLandLonLatDto(list,2);
    }

    private List<LandListedLonLat> listToEntity(List<List<String>> dataList,String landListedId) {
        List<LandListedLonLat> list = new ArrayList<>();
        for(int i = 0;i<dataList.size();i++){
            List<String> data = dataList.get(i);
            LandListedLonLat landListedLonLat = new LandListedLonLat();
            landListedLonLat.setLandListedId(landListedId);
            landListedLonLat.setLandLonLat(data.get(0));
            landListedLonLat.setLineWidth(data.get(1));
            landListedLonLat.setLineColor(data.get(2));
            landListedLonLat.setLineOpaqueness(data.get(3));
            landListedLonLat.setFillColor(data.get(4));
            landListedLonLat.setFillOpaqueness(data.get(5));
            try {
                String landLonLat = landListedLonLat.getLandLonLat();
                if(StrUtil.isNotEmpty(landLonLat)){
                    String[] split = landLonLat.split(";");
                    landListedLonLat.setLandLonLat(new StringBuffer(landLonLat).append(";").append(split[0]).toString());
                }
                landListedLonLat.setLandLonLat(WgsUtil.wgs84_To_Gcj02(landListedLonLat.getLandLonLat()));
            } catch (Exception e) {
                e.printStackTrace();
                throw new BusinessException("导入拟挂牌经纬度数据转换出错");
            }
            list.add(landListedLonLat);
        }
        return list;
    }
}
