package com.air.origin.controller;

import com.air.facilities.entity.Facilities;
import com.air.origin.dto.BlocksOriginQuery;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.cinderella.framework.common.core.util.R;
import com.air.origin.entity.BlocksOrigin;
import com.air.origin.service.BlocksOriginService;
import com.cinderella.framework.common.data.mybatis.QueryPage;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.*;

import java.util.List;


/**
 * 楼栋信息
 *
 * @author zeb
 * @date 2021-06-08 11:35:48
 */
@RestController
@AllArgsConstructor
@RequestMapping("/blocks_origin")
@Api(value = "blocks_origin", tags = "楼栋信息管理")
@Slf4j
public class BlocksOriginController {

    private final  BlocksOriginService blocksOriginService;

    /**
     * 分页查询
     * @param queryPage 分页对象
     * @param blocksOriginQuery 楼栋信息
     * @return
     */
    @ApiOperation(value = "分页查询", notes = "分页查询")
    @GetMapping("/page")
    public R<Page<BlocksOrigin>> getBlocksOriginPage(QueryPage queryPage, BlocksOriginQuery blocksOriginQuery,String city) {
        log.info("===================={}===={}",blocksOriginQuery,city);
        Page<BlocksOrigin> page = queryPage.toPage();
        List<BlocksOrigin> blocksOrigins = blocksOriginService.pageSer(page, blocksOriginQuery);
        return R.ok(page.setRecords(blocksOrigins),"查询成功");
    }


    /**
     * 通过id查询楼栋信息
     * @param blockId id
     * @return R
     */
    @ApiOperation(value = "通过id查询", notes = "通过id查询")
    @GetMapping("/{blockId}")
    public R getById(@PathVariable("blockId") Long blockId) {
        return R.ok(blocksOriginService.getById(blockId));
    }

    /**
     * 新增楼栋信息
     * @param blocksOrigin 楼栋信息
     * @return R
     */
    @ApiOperation(value = "新增楼栋信息", notes = "新增楼栋信息")
    @PostMapping
    public R save(@RequestBody BlocksOrigin blocksOrigin) {
        return R.ok(blocksOriginService.save(blocksOrigin));
    }

    /**
     * 修改楼栋信息
     * @param blocksOrigin 楼栋信息
     * @return R
     */
    @ApiOperation(value = "修改楼栋信息", notes = "修改楼栋信息")
    @PutMapping
    public R updateById(@RequestBody BlocksOrigin blocksOrigin) {
        return R.ok(blocksOriginService.updateById(blocksOrigin));
    }

    /**
     * 通过id删除楼栋信息
     * @param blockId id
     * @return R
     */
    @ApiOperation(value = "通过id删除楼栋信息", notes = "通过id删除楼栋信息")
    @DeleteMapping("/{blockId}")
    public R removeById(@PathVariable Long blockId) {
        return R.ok(blocksOriginService.removeById(blockId));
    }

    /**
     * 通过信息撤销楼栋信息
     * @param blocksOrigin id
     * @return R
     */
    @ApiOperation(value = "通过信息撤销楼栋信息", notes = "通过信息撤销楼栋信息")
    @PostMapping("/annul")
    public R removeById(@RequestBody BlocksOrigin blocksOrigin) {
        return R.ok(blocksOriginService.removeByIdAnnul(blocksOrigin));
    }
}
