package com.air.utils;

import com.cinderella.framework.common.core.util.LogUtil;
import com.cinderella.framework.common.minio.service.MinioTemplate;
import io.minio.messages.Bucket;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

import java.io.BufferedInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.HttpURLConnection;
import java.net.URL;
import java.util.Optional;


/**
 * @author peihao
 * @date 2020/12/7
 * @return
 **/
@Component
@Slf4j
public class FileUtil {

    @Autowired
    private MinioTemplate minioTemplate;

    @Value("${minio.down-url}")
    private String minioDownUrl;

    public String downloadFile(String bucketName, String fileName, String remoteFilePath, int time) {
        URL urlfile = null;
        HttpURLConnection httpUrl = null;
        InputStream inputStream = null;
        BufferedInputStream bis;
        String localUrl = null;
        try {
            urlfile = new URL(remoteFilePath);
            httpUrl = (HttpURLConnection) urlfile.openConnection();
            httpUrl.connect();
            inputStream = httpUrl.getInputStream();
            long fileLenth = httpUrl.getHeaderFieldLong("Content-Length", 0L);
            bis = new BufferedInputStream(inputStream);
            Optional<Bucket> bucket = minioTemplate.getBucket(bucketName);
            if (!bucket.isPresent()) {
                minioTemplate.createBucket(bucketName);
            }
            minioTemplate.putObject(bucketName, fileName, bis, fileLenth, "application/octet-stream");
            httpUrl.disconnect();
            localUrl = "/" + bucketName + "/" + fileName;
        } catch (Exception e) {
            e.printStackTrace();
            log.error(LogUtil.getlogInfo("sjt", "文件拉取失败", "文件拉取", "check", "bucketName：" + bucketName + "  fileName" + fileName + " remoteFilePath" + remoteFilePath + "  time" + time + " Exception:" + e));
            time++;
            if (time < 4) {
                downloadFile(bucketName, fileName, remoteFilePath, time);
            }
        } finally {
            try {
                inputStream.close();
            } catch (IOException e) {
                log.error(LogUtil.getlogInfo("sjt", "关闭文件流异常", "文件拉取", "check", "bucketName：" + bucketName + "  fileName" + fileName + " remoteFilePath" + remoteFilePath + "  time" + time + " Exception:" + e));
            }
        }
        return localUrl;
    }

    public String getUrlByInnerPath(String innerPath) {
        if (StringUtils.isEmpty(innerPath)) {
            return null;
        }
        return minioDownUrl + innerPath;
    }

    public String getInnerPath(String url) {
        if (StringUtils.isEmpty(url)) {
            return null;
        }
        try {
            String before = StringUtils.substringBefore(url, "?");
            String fileName = StringUtils.substringAfterLast(before, "/");
            String ipAndBucket = StringUtils.substringBeforeLast(before, "/");
            String bucket = StringUtils.substringAfterLast(ipAndBucket, "/");
            return "/" + bucket + "/" + fileName;
        } catch (Exception e) {
            log.error("解析文件地址出错:", e);
            return null;
        }
    }
}
